from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.rule_severity_level import RuleSeverityLevel
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_current_data_quality_status_model_checks import (
        ColumnCurrentDataQualityStatusModelChecks,
    )
    from ..models.column_current_data_quality_status_model_dimensions import (
        ColumnCurrentDataQualityStatusModelDimensions,
    )


T = TypeVar("T", bound="ColumnCurrentDataQualityStatusModel")


@_attrs_define
class ColumnCurrentDataQualityStatusModel:
    """The column's most recent data quality status. It is a summary of the results of the most recently executed data
    quality checks on the column. Verify the value of the current_severity to see if there are any data quality issues
    on the column.

        Attributes:
            current_severity (Union[Unset, RuleSeverityLevel]):
            highest_historical_severity (Union[Unset, RuleSeverityLevel]):
            last_check_executed_at (Union[Unset, int]): The UTC timestamp when the most recent data quality check was
                executed on the column.
            executed_checks (Union[Unset, int]): The total number of most recent checks that were executed on the column.
                Table comparison checks that are comparing groups of data are counted as the number of compared data groups.
            valid_results (Union[Unset, int]): The number of most recent valid data quality checks that passed without
                raising any issues.
            warnings (Union[Unset, int]): The number of most recent data quality checks that failed by raising a warning
                severity data quality issue.
            errors (Union[Unset, int]): The number of most recent data quality checks that failed by raising an error
                severity data quality issue.
            fatals (Union[Unset, int]): The number of most recent data quality checks that failed by raising a fatal
                severity data quality issue.
            execution_errors (Union[Unset, int]): The number of data quality check execution errors that were reported due
                to access issues to the data source, invalid mapping in DQOps, invalid queries in data quality sensors or
                invalid python rules. When an execution error is reported, the configuration of a data quality check on a column
                must be updated.
            data_quality_kpi (Union[Unset, float]): Data quality KPI score for the column, measured as a percentage of
                passed data quality checks. DQOps counts data quality issues at a warning severity level as passed checks. The
                data quality KPI score is a value in the range 0..100.
            checks (Union[Unset, ColumnCurrentDataQualityStatusModelChecks]): The dictionary of statuses for data quality
                checks. The keys are data quality check names, the values are the current data quality check statuses that
                describe the most current status.
            dimensions (Union[Unset, ColumnCurrentDataQualityStatusModelDimensions]): Dictionary of the current data quality
                statues for each data quality dimension.
    """

    current_severity: Union[Unset, RuleSeverityLevel] = UNSET
    highest_historical_severity: Union[Unset, RuleSeverityLevel] = UNSET
    last_check_executed_at: Union[Unset, int] = UNSET
    executed_checks: Union[Unset, int] = UNSET
    valid_results: Union[Unset, int] = UNSET
    warnings: Union[Unset, int] = UNSET
    errors: Union[Unset, int] = UNSET
    fatals: Union[Unset, int] = UNSET
    execution_errors: Union[Unset, int] = UNSET
    data_quality_kpi: Union[Unset, float] = UNSET
    checks: Union[Unset, "ColumnCurrentDataQualityStatusModelChecks"] = UNSET
    dimensions: Union[Unset, "ColumnCurrentDataQualityStatusModelDimensions"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        current_severity: Union[Unset, str] = UNSET
        if not isinstance(self.current_severity, Unset):
            current_severity = self.current_severity.value

        highest_historical_severity: Union[Unset, str] = UNSET
        if not isinstance(self.highest_historical_severity, Unset):
            highest_historical_severity = self.highest_historical_severity.value

        last_check_executed_at = self.last_check_executed_at
        executed_checks = self.executed_checks
        valid_results = self.valid_results
        warnings = self.warnings
        errors = self.errors
        fatals = self.fatals
        execution_errors = self.execution_errors
        data_quality_kpi = self.data_quality_kpi
        checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.checks, Unset):
            checks = self.checks.to_dict()

        dimensions: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.dimensions, Unset):
            dimensions = self.dimensions.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if current_severity is not UNSET:
            field_dict["current_severity"] = current_severity
        if highest_historical_severity is not UNSET:
            field_dict["highest_historical_severity"] = highest_historical_severity
        if last_check_executed_at is not UNSET:
            field_dict["last_check_executed_at"] = last_check_executed_at
        if executed_checks is not UNSET:
            field_dict["executed_checks"] = executed_checks
        if valid_results is not UNSET:
            field_dict["valid_results"] = valid_results
        if warnings is not UNSET:
            field_dict["warnings"] = warnings
        if errors is not UNSET:
            field_dict["errors"] = errors
        if fatals is not UNSET:
            field_dict["fatals"] = fatals
        if execution_errors is not UNSET:
            field_dict["execution_errors"] = execution_errors
        if data_quality_kpi is not UNSET:
            field_dict["data_quality_kpi"] = data_quality_kpi
        if checks is not UNSET:
            field_dict["checks"] = checks
        if dimensions is not UNSET:
            field_dict["dimensions"] = dimensions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_current_data_quality_status_model_checks import (
            ColumnCurrentDataQualityStatusModelChecks,
        )
        from ..models.column_current_data_quality_status_model_dimensions import (
            ColumnCurrentDataQualityStatusModelDimensions,
        )

        d = src_dict.copy()
        _current_severity = d.pop("current_severity", UNSET)
        current_severity: Union[Unset, RuleSeverityLevel]
        if isinstance(_current_severity, Unset):
            current_severity = UNSET
        else:
            current_severity = RuleSeverityLevel(_current_severity)

        _highest_historical_severity = d.pop("highest_historical_severity", UNSET)
        highest_historical_severity: Union[Unset, RuleSeverityLevel]
        if isinstance(_highest_historical_severity, Unset):
            highest_historical_severity = UNSET
        else:
            highest_historical_severity = RuleSeverityLevel(
                _highest_historical_severity
            )

        last_check_executed_at = d.pop("last_check_executed_at", UNSET)

        executed_checks = d.pop("executed_checks", UNSET)

        valid_results = d.pop("valid_results", UNSET)

        warnings = d.pop("warnings", UNSET)

        errors = d.pop("errors", UNSET)

        fatals = d.pop("fatals", UNSET)

        execution_errors = d.pop("execution_errors", UNSET)

        data_quality_kpi = d.pop("data_quality_kpi", UNSET)

        _checks = d.pop("checks", UNSET)
        checks: Union[Unset, ColumnCurrentDataQualityStatusModelChecks]
        if isinstance(_checks, Unset):
            checks = UNSET
        else:
            checks = ColumnCurrentDataQualityStatusModelChecks.from_dict(_checks)

        _dimensions = d.pop("dimensions", UNSET)
        dimensions: Union[Unset, ColumnCurrentDataQualityStatusModelDimensions]
        if isinstance(_dimensions, Unset):
            dimensions = UNSET
        else:
            dimensions = ColumnCurrentDataQualityStatusModelDimensions.from_dict(
                _dimensions
            )

        column_current_data_quality_status_model = cls(
            current_severity=current_severity,
            highest_historical_severity=highest_historical_severity,
            last_check_executed_at=last_check_executed_at,
            executed_checks=executed_checks,
            valid_results=valid_results,
            warnings=warnings,
            errors=errors,
            fatals=fatals,
            execution_errors=execution_errors,
            data_quality_kpi=data_quality_kpi,
            checks=checks,
            dimensions=dimensions,
        )

        column_current_data_quality_status_model.additional_properties = d
        return column_current_data_quality_status_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ScheduleEnabledStatusModel(str, Enum):
    DISABLED = "disabled"
    ENABLED = "enabled"
    NOT_CONFIGURED = "not_configured"
    OVERRIDDEN_BY_CHECKS = "overridden_by_checks"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.statistics_collector_target import StatisticsCollectorTarget
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.hierarchy_id_model import HierarchyIdModel


T = TypeVar("T", bound="StatisticsCollectorSearchFilters")


@_attrs_define
class StatisticsCollectorSearchFilters:
    r"""
    Attributes:
        connection (Union[Unset, str]): The connection (data source) name. Supports search patterns in the format:
            'source\*', '\*_prod', 'prefix\*suffix'.
        full_table_name (Union[Unset, str]): The schema and table name. It is provided as *<schema_name>.<table_name>*,
            for example *public.fact_sales*. The schema and table name accept patterns both in the schema name and table
            name parts. Sample patterns are: 'schema_name.tab_prefix_\*', 'schema_name.*', '*.*', 'schema_name.\*_customer',
            'schema_name.tab_\*_suffix'.
        enabled (Union[Unset, bool]): A boolean flag to target enabled tables, columns or checks. When the value of this
            field is not set, the default value of this field is *true*, targeting only tables, columns and checks that are
            not implicitly disabled.
        tags (Union[Unset, List[str]]): An array of tags assigned to the table. All tags must be present on a table to
            match. The tags can use patterns:  'prefix\*', '\*suffix', 'prefix\*suffix'. The tags are assigned to the table
            on the data grouping screen when any of the data grouping hierarchy level is assigned a static value, which is a
            tag.
        labels (Union[Unset, List[str]]): An array of labels assigned to the table. All labels must be present on a
            table to match. The labels can use patterns:  'prefix\*', '\*suffix', 'prefix\*suffix'. The labels are assigned
            on the labels screen and stored in the *labels* node in the *.dqotable.yaml* file.
        max_results (Union[Unset, int]): Optional limit for the maximum number of results to return.
        column_names (Union[Unset, List[str]]): The list of column names or column name patters. This field accepts
            search patterns in the format: 'fk_\*', '\*_id', 'prefix\*suffix'.
        collector_name (Union[Unset, str]): The target statistics collector name to capture only selected statistics.
            Uses the short collector nameThis field supports search patterns such as: 'prefix\*', '\*suffix',
            'prefix_\*_suffix'. In order to collect only top 10 most common column samples, use 'column_samples'.
        sensor_name (Union[Unset, str]): The target sensor name to run only data quality checks that are using this
            sensor. Uses the full sensor name which is the full folder path within the *sensors* folder. This field supports
            search patterns such as: 'table/volume/row_\*', '\*_count', 'table/volume/prefix_\*_suffix'.
        collector_category (Union[Unset, str]): The target statistics collector category, for example: *nulls*,
            *volume*, *sampling*.
        target (Union[Unset, StatisticsCollectorTarget]):
        enabled_cron_schedule_expression (Union[Unset, str]): Expected CRON profiling schedule.
        collectors_hierarchy_ids_models (Union[Unset, List['HierarchyIdModel']]):
    """

    connection: Union[Unset, str] = UNSET
    full_table_name: Union[Unset, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    tags: Union[Unset, List[str]] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    max_results: Union[Unset, int] = UNSET
    column_names: Union[Unset, List[str]] = UNSET
    collector_name: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    collector_category: Union[Unset, str] = UNSET
    target: Union[Unset, StatisticsCollectorTarget] = UNSET
    enabled_cron_schedule_expression: Union[Unset, str] = UNSET
    collectors_hierarchy_ids_models: Union[Unset, List["HierarchyIdModel"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection = self.connection
        full_table_name = self.full_table_name
        enabled = self.enabled
        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        max_results = self.max_results
        column_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.column_names, Unset):
            column_names = self.column_names

        collector_name = self.collector_name
        sensor_name = self.sensor_name
        collector_category = self.collector_category
        target: Union[Unset, str] = UNSET
        if not isinstance(self.target, Unset):
            target = self.target.value

        enabled_cron_schedule_expression = self.enabled_cron_schedule_expression
        collectors_hierarchy_ids_models: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.collectors_hierarchy_ids_models, Unset):
            collectors_hierarchy_ids_models = []
            for (
                collectors_hierarchy_ids_models_item_data
            ) in self.collectors_hierarchy_ids_models:
                collectors_hierarchy_ids_models_item = (
                    collectors_hierarchy_ids_models_item_data.to_dict()
                )

                collectors_hierarchy_ids_models.append(
                    collectors_hierarchy_ids_models_item
                )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection is not UNSET:
            field_dict["connection"] = connection
        if full_table_name is not UNSET:
            field_dict["fullTableName"] = full_table_name
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if tags is not UNSET:
            field_dict["tags"] = tags
        if labels is not UNSET:
            field_dict["labels"] = labels
        if max_results is not UNSET:
            field_dict["maxResults"] = max_results
        if column_names is not UNSET:
            field_dict["columnNames"] = column_names
        if collector_name is not UNSET:
            field_dict["collectorName"] = collector_name
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if collector_category is not UNSET:
            field_dict["collectorCategory"] = collector_category
        if target is not UNSET:
            field_dict["target"] = target
        if enabled_cron_schedule_expression is not UNSET:
            field_dict["enabledCronScheduleExpression"] = (
                enabled_cron_schedule_expression
            )
        if collectors_hierarchy_ids_models is not UNSET:
            field_dict["collectorsHierarchyIdsModels"] = collectors_hierarchy_ids_models

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.hierarchy_id_model import HierarchyIdModel

        d = src_dict.copy()
        connection = d.pop("connection", UNSET)

        full_table_name = d.pop("fullTableName", UNSET)

        enabled = d.pop("enabled", UNSET)

        tags = cast(List[str], d.pop("tags", UNSET))

        labels = cast(List[str], d.pop("labels", UNSET))

        max_results = d.pop("maxResults", UNSET)

        column_names = cast(List[str], d.pop("columnNames", UNSET))

        collector_name = d.pop("collectorName", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        collector_category = d.pop("collectorCategory", UNSET)

        _target = d.pop("target", UNSET)
        target: Union[Unset, StatisticsCollectorTarget]
        if isinstance(_target, Unset):
            target = UNSET
        else:
            target = StatisticsCollectorTarget(_target)

        enabled_cron_schedule_expression = d.pop("enabledCronScheduleExpression", UNSET)

        collectors_hierarchy_ids_models = []
        _collectors_hierarchy_ids_models = d.pop("collectorsHierarchyIdsModels", UNSET)
        for collectors_hierarchy_ids_models_item_data in (
            _collectors_hierarchy_ids_models or []
        ):
            collectors_hierarchy_ids_models_item = HierarchyIdModel.from_dict(
                collectors_hierarchy_ids_models_item_data
            )

            collectors_hierarchy_ids_models.append(collectors_hierarchy_ids_models_item)

        statistics_collector_search_filters = cls(
            connection=connection,
            full_table_name=full_table_name,
            enabled=enabled,
            tags=tags,
            labels=labels,
            max_results=max_results,
            column_names=column_names,
            collector_name=collector_name,
            sensor_name=sensor_name,
            collector_category=collector_category,
            target=target,
            enabled_cron_schedule_expression=enabled_cron_schedule_expression,
            collectors_hierarchy_ids_models=collectors_hierarchy_ids_models,
        )

        statistics_collector_search_filters.additional_properties = d
        return statistics_collector_search_filters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.provider_sensor_runner_type import ProviderSensorRunnerType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.provider_sensor_definition_spec_parameters import (
        ProviderSensorDefinitionSpecParameters,
    )


T = TypeVar("T", bound="ProviderSensorDefinitionSpec")


@_attrs_define
class ProviderSensorDefinitionSpec:
    """
    Attributes:
        type (Union[Unset, ProviderSensorRunnerType]):
        java_class_name (Union[Unset, str]): Java class name for a sensor runner that will execute the sensor. The
            "type" must be "java_class".
        supports_grouping (Union[Unset, bool]): The sensor supports grouping, using the GROUP BY clause in SQL. Sensors
            that support a GROUP BY condition can capture separate data quality scores for each data group. The default
            value is true, because most of the data quality sensor support grouping.
        supports_partitioned_checks (Union[Unset, bool]): The sensor supports grouping by a partition date, using the
            GROUP BY clause in SQL. Sensors that support grouping by a partition_by_column can be used for partition checks,
            calculating separate data quality metrics for each daily/monthly partition. The default value is true, because
            most of the data quality sensor support partitioned checks.
        parameters (Union[Unset, ProviderSensorDefinitionSpecParameters]): Additional provider specific sensor
            parameters
        disable_merging_queries (Union[Unset, bool]): Disables merging this sensor's SQL with other sensors. When this
            parameter is 'true', the sensor's SQL will be executed as an independent query.
    """

    type: Union[Unset, ProviderSensorRunnerType] = UNSET
    java_class_name: Union[Unset, str] = UNSET
    supports_grouping: Union[Unset, bool] = UNSET
    supports_partitioned_checks: Union[Unset, bool] = UNSET
    parameters: Union[Unset, "ProviderSensorDefinitionSpecParameters"] = UNSET
    disable_merging_queries: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        java_class_name = self.java_class_name
        supports_grouping = self.supports_grouping
        supports_partitioned_checks = self.supports_partitioned_checks
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        disable_merging_queries = self.disable_merging_queries

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type is not UNSET:
            field_dict["type"] = type
        if java_class_name is not UNSET:
            field_dict["java_class_name"] = java_class_name
        if supports_grouping is not UNSET:
            field_dict["supports_grouping"] = supports_grouping
        if supports_partitioned_checks is not UNSET:
            field_dict["supports_partitioned_checks"] = supports_partitioned_checks
        if parameters is not UNSET:
            field_dict["parameters"] = parameters
        if disable_merging_queries is not UNSET:
            field_dict["disable_merging_queries"] = disable_merging_queries

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.provider_sensor_definition_spec_parameters import (
            ProviderSensorDefinitionSpecParameters,
        )

        d = src_dict.copy()
        _type = d.pop("type", UNSET)
        type: Union[Unset, ProviderSensorRunnerType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = ProviderSensorRunnerType(_type)

        java_class_name = d.pop("java_class_name", UNSET)

        supports_grouping = d.pop("supports_grouping", UNSET)

        supports_partitioned_checks = d.pop("supports_partitioned_checks", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, ProviderSensorDefinitionSpecParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = ProviderSensorDefinitionSpecParameters.from_dict(_parameters)

        disable_merging_queries = d.pop("disable_merging_queries", UNSET)

        provider_sensor_definition_spec = cls(
            type=type,
            java_class_name=java_class_name,
            supports_grouping=supports_grouping,
            supports_partitioned_checks=supports_partitioned_checks,
            parameters=parameters,
            disable_merging_queries=disable_merging_queries,
        )

        provider_sensor_definition_spec.additional_properties = d
        return provider_sensor_definition_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.provider_type import ProviderType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ProviderSensorListModel")


@_attrs_define
class ProviderSensorListModel:
    """Provider sensor list model

    Attributes:
        provider_type (Union[Unset, ProviderType]):
        custom (Union[Unset, bool]): This connection specific template is a custom sensor template or was customized by
            the user.
        built_in (Union[Unset, bool]): This connection specific template is provided with DQOps as a built-in sensor.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
    """

    provider_type: Union[Unset, ProviderType] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provider_type: Union[Unset, str] = UNSET
        if not isinstance(self.provider_type, Unset):
            provider_type = self.provider_type.value

        custom = self.custom
        built_in = self.built_in
        can_edit = self.can_edit

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if provider_type is not UNSET:
            field_dict["provider_type"] = provider_type
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _provider_type = d.pop("provider_type", UNSET)
        provider_type: Union[Unset, ProviderType]
        if isinstance(_provider_type, Unset):
            provider_type = UNSET
        else:
            provider_type = ProviderType(_provider_type)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        provider_sensor_list_model = cls(
            provider_type=provider_type,
            custom=custom,
            built_in=built_in,
            can_edit=can_edit,
        )

        provider_sensor_list_model.additional_properties = d
        return provider_sensor_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.incident_status import IncidentStatus
from ...models.top_incident_grouping import TopIncidentGrouping
from ...models.top_incidents_model import TopIncidentsModel
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    status: Union[Unset, None, IncidentStatus] = UNSET,
    group_by: Union[Unset, None, TopIncidentGrouping] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    days: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    json_status: Union[Unset, None, str] = UNSET
    if not isinstance(status, Unset):
        json_status = status.value if status else None

    params["status"] = json_status

    json_group_by: Union[Unset, None, str] = UNSET
    if not isinstance(group_by, Unset):
        json_group_by = group_by.value if group_by else None

    params["groupBy"] = json_group_by

    params["limit"] = limit

    params["days"] = days

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/topincidents",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[TopIncidentsModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = TopIncidentsModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[TopIncidentsModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    status: Union[Unset, None, IncidentStatus] = UNSET,
    group_by: Union[Unset, None, TopIncidentGrouping] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    days: Union[Unset, None, int] = UNSET,
) -> Response[TopIncidentsModel]:
    """findTopIncidentsGrouped

     Finds the most recent incidents grouped by one of the incident's attribute, such as a data quality
    dimension, a data quality check category or the connection name.

    Args:
        status (Union[Unset, None, IncidentStatus]):
        group_by (Union[Unset, None, TopIncidentGrouping]):
        limit (Union[Unset, None, int]):
        days (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TopIncidentsModel]
    """

    kwargs = _get_kwargs(
        status=status,
        group_by=group_by,
        limit=limit,
        days=days,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    status: Union[Unset, None, IncidentStatus] = UNSET,
    group_by: Union[Unset, None, TopIncidentGrouping] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    days: Union[Unset, None, int] = UNSET,
) -> Optional[TopIncidentsModel]:
    """findTopIncidentsGrouped

     Finds the most recent incidents grouped by one of the incident's attribute, such as a data quality
    dimension, a data quality check category or the connection name.

    Args:
        status (Union[Unset, None, IncidentStatus]):
        group_by (Union[Unset, None, TopIncidentGrouping]):
        limit (Union[Unset, None, int]):
        days (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TopIncidentsModel
    """

    return sync_detailed(
        client=client,
        status=status,
        group_by=group_by,
        limit=limit,
        days=days,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    status: Union[Unset, None, IncidentStatus] = UNSET,
    group_by: Union[Unset, None, TopIncidentGrouping] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    days: Union[Unset, None, int] = UNSET,
) -> Response[TopIncidentsModel]:
    """findTopIncidentsGrouped

     Finds the most recent incidents grouped by one of the incident's attribute, such as a data quality
    dimension, a data quality check category or the connection name.

    Args:
        status (Union[Unset, None, IncidentStatus]):
        group_by (Union[Unset, None, TopIncidentGrouping]):
        limit (Union[Unset, None, int]):
        days (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TopIncidentsModel]
    """

    kwargs = _get_kwargs(
        status=status,
        group_by=group_by,
        limit=limit,
        days=days,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    status: Union[Unset, None, IncidentStatus] = UNSET,
    group_by: Union[Unset, None, TopIncidentGrouping] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    days: Union[Unset, None, int] = UNSET,
) -> Optional[TopIncidentsModel]:
    """findTopIncidentsGrouped

     Finds the most recent incidents grouped by one of the incident's attribute, such as a data quality
    dimension, a data quality check category or the connection name.

    Args:
        status (Union[Unset, None, IncidentStatus]):
        group_by (Union[Unset, None, TopIncidentGrouping]):
        limit (Union[Unset, None, int]):
        days (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TopIncidentsModel
    """

    return (
        await asyncio_detailed(
            client=client,
            status=status,
            group_by=group_by,
            limit=limit,
            days=days,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_data_freshness_anomaly_check_spec import (
        TableDataFreshnessAnomalyCheckSpec,
    )
    from ..models.table_data_freshness_check_spec import TableDataFreshnessCheckSpec
    from ..models.table_data_ingestion_delay_check_spec import (
        TableDataIngestionDelayCheckSpec,
    )
    from ..models.table_data_staleness_check_spec import TableDataStalenessCheckSpec
    from ..models.table_timeliness_profiling_checks_spec_custom_checks import (
        TableTimelinessProfilingChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="TableTimelinessProfilingChecksSpec")


@_attrs_define
class TableTimelinessProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableTimelinessProfilingChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        profile_data_freshness (Union[Unset, TableDataFreshnessCheckSpec]):
        profile_data_freshness_anomaly (Union[Unset, TableDataFreshnessAnomalyCheckSpec]):
        profile_data_staleness (Union[Unset, TableDataStalenessCheckSpec]):
        profile_data_ingestion_delay (Union[Unset, TableDataIngestionDelayCheckSpec]):
    """

    custom_checks: Union[Unset, "TableTimelinessProfilingChecksSpecCustomChecks"] = (
        UNSET
    )
    profile_data_freshness: Union[Unset, "TableDataFreshnessCheckSpec"] = UNSET
    profile_data_freshness_anomaly: Union[
        Unset, "TableDataFreshnessAnomalyCheckSpec"
    ] = UNSET
    profile_data_staleness: Union[Unset, "TableDataStalenessCheckSpec"] = UNSET
    profile_data_ingestion_delay: Union[Unset, "TableDataIngestionDelayCheckSpec"] = (
        UNSET
    )
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_data_freshness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_freshness, Unset):
            profile_data_freshness = self.profile_data_freshness.to_dict()

        profile_data_freshness_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_freshness_anomaly, Unset):
            profile_data_freshness_anomaly = (
                self.profile_data_freshness_anomaly.to_dict()
            )

        profile_data_staleness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_staleness, Unset):
            profile_data_staleness = self.profile_data_staleness.to_dict()

        profile_data_ingestion_delay: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_ingestion_delay, Unset):
            profile_data_ingestion_delay = self.profile_data_ingestion_delay.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_data_freshness is not UNSET:
            field_dict["profile_data_freshness"] = profile_data_freshness
        if profile_data_freshness_anomaly is not UNSET:
            field_dict["profile_data_freshness_anomaly"] = (
                profile_data_freshness_anomaly
            )
        if profile_data_staleness is not UNSET:
            field_dict["profile_data_staleness"] = profile_data_staleness
        if profile_data_ingestion_delay is not UNSET:
            field_dict["profile_data_ingestion_delay"] = profile_data_ingestion_delay

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_data_freshness_anomaly_check_spec import (
            TableDataFreshnessAnomalyCheckSpec,
        )
        from ..models.table_data_freshness_check_spec import TableDataFreshnessCheckSpec
        from ..models.table_data_ingestion_delay_check_spec import (
            TableDataIngestionDelayCheckSpec,
        )
        from ..models.table_data_staleness_check_spec import TableDataStalenessCheckSpec
        from ..models.table_timeliness_profiling_checks_spec_custom_checks import (
            TableTimelinessProfilingChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, TableTimelinessProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = TableTimelinessProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_data_freshness = d.pop("profile_data_freshness", UNSET)
        profile_data_freshness: Union[Unset, TableDataFreshnessCheckSpec]
        if isinstance(_profile_data_freshness, Unset):
            profile_data_freshness = UNSET
        else:
            profile_data_freshness = TableDataFreshnessCheckSpec.from_dict(
                _profile_data_freshness
            )

        _profile_data_freshness_anomaly = d.pop("profile_data_freshness_anomaly", UNSET)
        profile_data_freshness_anomaly: Union[Unset, TableDataFreshnessAnomalyCheckSpec]
        if isinstance(_profile_data_freshness_anomaly, Unset):
            profile_data_freshness_anomaly = UNSET
        else:
            profile_data_freshness_anomaly = (
                TableDataFreshnessAnomalyCheckSpec.from_dict(
                    _profile_data_freshness_anomaly
                )
            )

        _profile_data_staleness = d.pop("profile_data_staleness", UNSET)
        profile_data_staleness: Union[Unset, TableDataStalenessCheckSpec]
        if isinstance(_profile_data_staleness, Unset):
            profile_data_staleness = UNSET
        else:
            profile_data_staleness = TableDataStalenessCheckSpec.from_dict(
                _profile_data_staleness
            )

        _profile_data_ingestion_delay = d.pop("profile_data_ingestion_delay", UNSET)
        profile_data_ingestion_delay: Union[Unset, TableDataIngestionDelayCheckSpec]
        if isinstance(_profile_data_ingestion_delay, Unset):
            profile_data_ingestion_delay = UNSET
        else:
            profile_data_ingestion_delay = TableDataIngestionDelayCheckSpec.from_dict(
                _profile_data_ingestion_delay
            )

        table_timeliness_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_data_freshness=profile_data_freshness,
            profile_data_freshness_anomaly=profile_data_freshness_anomaly,
            profile_data_staleness=profile_data_staleness,
            profile_data_ingestion_delay=profile_data_ingestion_delay,
        )

        table_timeliness_profiling_checks_spec.additional_properties = d
        return table_timeliness_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_text_length_above_max_length_check_spec import (
        ColumnTextLengthAboveMaxLengthCheckSpec,
    )
    from ..models.column_text_length_above_max_length_percent_check_spec import (
        ColumnTextLengthAboveMaxLengthPercentCheckSpec,
    )
    from ..models.column_text_length_below_min_length_check_spec import (
        ColumnTextLengthBelowMinLengthCheckSpec,
    )
    from ..models.column_text_length_below_min_length_percent_check_spec import (
        ColumnTextLengthBelowMinLengthPercentCheckSpec,
    )
    from ..models.column_text_length_in_range_percent_check_spec import (
        ColumnTextLengthInRangePercentCheckSpec,
    )
    from ..models.column_text_max_length_check_spec import ColumnTextMaxLengthCheckSpec
    from ..models.column_text_max_word_count_check_spec import (
        ColumnTextMaxWordCountCheckSpec,
    )
    from ..models.column_text_mean_length_check_spec import (
        ColumnTextMeanLengthCheckSpec,
    )
    from ..models.column_text_min_length_check_spec import ColumnTextMinLengthCheckSpec
    from ..models.column_text_min_word_count_check_spec import (
        ColumnTextMinWordCountCheckSpec,
    )
    from ..models.column_text_monthly_monitoring_checks_spec_custom_checks import (
        ColumnTextMonthlyMonitoringChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="ColumnTextMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnTextMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnTextMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        monthly_text_min_length (Union[Unset, ColumnTextMinLengthCheckSpec]):
        monthly_text_max_length (Union[Unset, ColumnTextMaxLengthCheckSpec]):
        monthly_text_mean_length (Union[Unset, ColumnTextMeanLengthCheckSpec]):
        monthly_text_length_below_min_length (Union[Unset, ColumnTextLengthBelowMinLengthCheckSpec]):
        monthly_text_length_below_min_length_percent (Union[Unset, ColumnTextLengthBelowMinLengthPercentCheckSpec]):
        monthly_text_length_above_max_length (Union[Unset, ColumnTextLengthAboveMaxLengthCheckSpec]):
        monthly_text_length_above_max_length_percent (Union[Unset, ColumnTextLengthAboveMaxLengthPercentCheckSpec]):
        monthly_text_length_in_range_percent (Union[Unset, ColumnTextLengthInRangePercentCheckSpec]):
        monthly_min_word_count (Union[Unset, ColumnTextMinWordCountCheckSpec]):
        monthly_max_word_count (Union[Unset, ColumnTextMaxWordCountCheckSpec]):
    """

    custom_checks: Union[Unset, "ColumnTextMonthlyMonitoringChecksSpecCustomChecks"] = (
        UNSET
    )
    monthly_text_min_length: Union[Unset, "ColumnTextMinLengthCheckSpec"] = UNSET
    monthly_text_max_length: Union[Unset, "ColumnTextMaxLengthCheckSpec"] = UNSET
    monthly_text_mean_length: Union[Unset, "ColumnTextMeanLengthCheckSpec"] = UNSET
    monthly_text_length_below_min_length: Union[
        Unset, "ColumnTextLengthBelowMinLengthCheckSpec"
    ] = UNSET
    monthly_text_length_below_min_length_percent: Union[
        Unset, "ColumnTextLengthBelowMinLengthPercentCheckSpec"
    ] = UNSET
    monthly_text_length_above_max_length: Union[
        Unset, "ColumnTextLengthAboveMaxLengthCheckSpec"
    ] = UNSET
    monthly_text_length_above_max_length_percent: Union[
        Unset, "ColumnTextLengthAboveMaxLengthPercentCheckSpec"
    ] = UNSET
    monthly_text_length_in_range_percent: Union[
        Unset, "ColumnTextLengthInRangePercentCheckSpec"
    ] = UNSET
    monthly_min_word_count: Union[Unset, "ColumnTextMinWordCountCheckSpec"] = UNSET
    monthly_max_word_count: Union[Unset, "ColumnTextMaxWordCountCheckSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_text_min_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_text_min_length, Unset):
            monthly_text_min_length = self.monthly_text_min_length.to_dict()

        monthly_text_max_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_text_max_length, Unset):
            monthly_text_max_length = self.monthly_text_max_length.to_dict()

        monthly_text_mean_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_text_mean_length, Unset):
            monthly_text_mean_length = self.monthly_text_mean_length.to_dict()

        monthly_text_length_below_min_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_text_length_below_min_length, Unset):
            monthly_text_length_below_min_length = (
                self.monthly_text_length_below_min_length.to_dict()
            )

        monthly_text_length_below_min_length_percent: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.monthly_text_length_below_min_length_percent, Unset):
            monthly_text_length_below_min_length_percent = (
                self.monthly_text_length_below_min_length_percent.to_dict()
            )

        monthly_text_length_above_max_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_text_length_above_max_length, Unset):
            monthly_text_length_above_max_length = (
                self.monthly_text_length_above_max_length.to_dict()
            )

        monthly_text_length_above_max_length_percent: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.monthly_text_length_above_max_length_percent, Unset):
            monthly_text_length_above_max_length_percent = (
                self.monthly_text_length_above_max_length_percent.to_dict()
            )

        monthly_text_length_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_text_length_in_range_percent, Unset):
            monthly_text_length_in_range_percent = (
                self.monthly_text_length_in_range_percent.to_dict()
            )

        monthly_min_word_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_min_word_count, Unset):
            monthly_min_word_count = self.monthly_min_word_count.to_dict()

        monthly_max_word_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_max_word_count, Unset):
            monthly_max_word_count = self.monthly_max_word_count.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_text_min_length is not UNSET:
            field_dict["monthly_text_min_length"] = monthly_text_min_length
        if monthly_text_max_length is not UNSET:
            field_dict["monthly_text_max_length"] = monthly_text_max_length
        if monthly_text_mean_length is not UNSET:
            field_dict["monthly_text_mean_length"] = monthly_text_mean_length
        if monthly_text_length_below_min_length is not UNSET:
            field_dict["monthly_text_length_below_min_length"] = (
                monthly_text_length_below_min_length
            )
        if monthly_text_length_below_min_length_percent is not UNSET:
            field_dict["monthly_text_length_below_min_length_percent"] = (
                monthly_text_length_below_min_length_percent
            )
        if monthly_text_length_above_max_length is not UNSET:
            field_dict["monthly_text_length_above_max_length"] = (
                monthly_text_length_above_max_length
            )
        if monthly_text_length_above_max_length_percent is not UNSET:
            field_dict["monthly_text_length_above_max_length_percent"] = (
                monthly_text_length_above_max_length_percent
            )
        if monthly_text_length_in_range_percent is not UNSET:
            field_dict["monthly_text_length_in_range_percent"] = (
                monthly_text_length_in_range_percent
            )
        if monthly_min_word_count is not UNSET:
            field_dict["monthly_min_word_count"] = monthly_min_word_count
        if monthly_max_word_count is not UNSET:
            field_dict["monthly_max_word_count"] = monthly_max_word_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_text_length_above_max_length_check_spec import (
            ColumnTextLengthAboveMaxLengthCheckSpec,
        )
        from ..models.column_text_length_above_max_length_percent_check_spec import (
            ColumnTextLengthAboveMaxLengthPercentCheckSpec,
        )
        from ..models.column_text_length_below_min_length_check_spec import (
            ColumnTextLengthBelowMinLengthCheckSpec,
        )
        from ..models.column_text_length_below_min_length_percent_check_spec import (
            ColumnTextLengthBelowMinLengthPercentCheckSpec,
        )
        from ..models.column_text_length_in_range_percent_check_spec import (
            ColumnTextLengthInRangePercentCheckSpec,
        )
        from ..models.column_text_max_length_check_spec import (
            ColumnTextMaxLengthCheckSpec,
        )
        from ..models.column_text_max_word_count_check_spec import (
            ColumnTextMaxWordCountCheckSpec,
        )
        from ..models.column_text_mean_length_check_spec import (
            ColumnTextMeanLengthCheckSpec,
        )
        from ..models.column_text_min_length_check_spec import (
            ColumnTextMinLengthCheckSpec,
        )
        from ..models.column_text_min_word_count_check_spec import (
            ColumnTextMinWordCountCheckSpec,
        )
        from ..models.column_text_monthly_monitoring_checks_spec_custom_checks import (
            ColumnTextMonthlyMonitoringChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnTextMonthlyMonitoringChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = ColumnTextMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _monthly_text_min_length = d.pop("monthly_text_min_length", UNSET)
        monthly_text_min_length: Union[Unset, ColumnTextMinLengthCheckSpec]
        if isinstance(_monthly_text_min_length, Unset):
            monthly_text_min_length = UNSET
        else:
            monthly_text_min_length = ColumnTextMinLengthCheckSpec.from_dict(
                _monthly_text_min_length
            )

        _monthly_text_max_length = d.pop("monthly_text_max_length", UNSET)
        monthly_text_max_length: Union[Unset, ColumnTextMaxLengthCheckSpec]
        if isinstance(_monthly_text_max_length, Unset):
            monthly_text_max_length = UNSET
        else:
            monthly_text_max_length = ColumnTextMaxLengthCheckSpec.from_dict(
                _monthly_text_max_length
            )

        _monthly_text_mean_length = d.pop("monthly_text_mean_length", UNSET)
        monthly_text_mean_length: Union[Unset, ColumnTextMeanLengthCheckSpec]
        if isinstance(_monthly_text_mean_length, Unset):
            monthly_text_mean_length = UNSET
        else:
            monthly_text_mean_length = ColumnTextMeanLengthCheckSpec.from_dict(
                _monthly_text_mean_length
            )

        _monthly_text_length_below_min_length = d.pop(
            "monthly_text_length_below_min_length", UNSET
        )
        monthly_text_length_below_min_length: Union[
            Unset, ColumnTextLengthBelowMinLengthCheckSpec
        ]
        if isinstance(_monthly_text_length_below_min_length, Unset):
            monthly_text_length_below_min_length = UNSET
        else:
            monthly_text_length_below_min_length = (
                ColumnTextLengthBelowMinLengthCheckSpec.from_dict(
                    _monthly_text_length_below_min_length
                )
            )

        _monthly_text_length_below_min_length_percent = d.pop(
            "monthly_text_length_below_min_length_percent", UNSET
        )
        monthly_text_length_below_min_length_percent: Union[
            Unset, ColumnTextLengthBelowMinLengthPercentCheckSpec
        ]
        if isinstance(_monthly_text_length_below_min_length_percent, Unset):
            monthly_text_length_below_min_length_percent = UNSET
        else:
            monthly_text_length_below_min_length_percent = (
                ColumnTextLengthBelowMinLengthPercentCheckSpec.from_dict(
                    _monthly_text_length_below_min_length_percent
                )
            )

        _monthly_text_length_above_max_length = d.pop(
            "monthly_text_length_above_max_length", UNSET
        )
        monthly_text_length_above_max_length: Union[
            Unset, ColumnTextLengthAboveMaxLengthCheckSpec
        ]
        if isinstance(_monthly_text_length_above_max_length, Unset):
            monthly_text_length_above_max_length = UNSET
        else:
            monthly_text_length_above_max_length = (
                ColumnTextLengthAboveMaxLengthCheckSpec.from_dict(
                    _monthly_text_length_above_max_length
                )
            )

        _monthly_text_length_above_max_length_percent = d.pop(
            "monthly_text_length_above_max_length_percent", UNSET
        )
        monthly_text_length_above_max_length_percent: Union[
            Unset, ColumnTextLengthAboveMaxLengthPercentCheckSpec
        ]
        if isinstance(_monthly_text_length_above_max_length_percent, Unset):
            monthly_text_length_above_max_length_percent = UNSET
        else:
            monthly_text_length_above_max_length_percent = (
                ColumnTextLengthAboveMaxLengthPercentCheckSpec.from_dict(
                    _monthly_text_length_above_max_length_percent
                )
            )

        _monthly_text_length_in_range_percent = d.pop(
            "monthly_text_length_in_range_percent", UNSET
        )
        monthly_text_length_in_range_percent: Union[
            Unset, ColumnTextLengthInRangePercentCheckSpec
        ]
        if isinstance(_monthly_text_length_in_range_percent, Unset):
            monthly_text_length_in_range_percent = UNSET
        else:
            monthly_text_length_in_range_percent = (
                ColumnTextLengthInRangePercentCheckSpec.from_dict(
                    _monthly_text_length_in_range_percent
                )
            )

        _monthly_min_word_count = d.pop("monthly_min_word_count", UNSET)
        monthly_min_word_count: Union[Unset, ColumnTextMinWordCountCheckSpec]
        if isinstance(_monthly_min_word_count, Unset):
            monthly_min_word_count = UNSET
        else:
            monthly_min_word_count = ColumnTextMinWordCountCheckSpec.from_dict(
                _monthly_min_word_count
            )

        _monthly_max_word_count = d.pop("monthly_max_word_count", UNSET)
        monthly_max_word_count: Union[Unset, ColumnTextMaxWordCountCheckSpec]
        if isinstance(_monthly_max_word_count, Unset):
            monthly_max_word_count = UNSET
        else:
            monthly_max_word_count = ColumnTextMaxWordCountCheckSpec.from_dict(
                _monthly_max_word_count
            )

        column_text_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_text_min_length=monthly_text_min_length,
            monthly_text_max_length=monthly_text_max_length,
            monthly_text_mean_length=monthly_text_mean_length,
            monthly_text_length_below_min_length=monthly_text_length_below_min_length,
            monthly_text_length_below_min_length_percent=monthly_text_length_below_min_length_percent,
            monthly_text_length_above_max_length=monthly_text_length_above_max_length,
            monthly_text_length_above_max_length_percent=monthly_text_length_above_max_length_percent,
            monthly_text_length_in_range_percent=monthly_text_length_in_range_percent,
            monthly_min_word_count=monthly_min_word_count,
            monthly_max_word_count=monthly_max_word_count,
        )

        column_text_monthly_monitoring_checks_spec.additional_properties = d
        return column_text_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CheckType(str, Enum):
    MONITORING = "monitoring"
    PARTITIONED = "partitioned"
    PROFILING = "profiling"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_datatype_daily_monitoring_checks_spec_custom_checks import (
        ColumnDatatypeDailyMonitoringChecksSpecCustomChecks,
    )
    from ..models.column_datatype_detected_datatype_in_text_changed_check_spec import (
        ColumnDatatypeDetectedDatatypeInTextChangedCheckSpec,
    )
    from ..models.column_detected_datatype_in_text_check_spec import (
        ColumnDetectedDatatypeInTextCheckSpec,
    )


T = TypeVar("T", bound="ColumnDatatypeDailyMonitoringChecksSpec")


@_attrs_define
class ColumnDatatypeDailyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnDatatypeDailyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        daily_detected_datatype_in_text (Union[Unset, ColumnDetectedDatatypeInTextCheckSpec]):
        daily_detected_datatype_in_text_changed (Union[Unset, ColumnDatatypeDetectedDatatypeInTextChangedCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnDatatypeDailyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    daily_detected_datatype_in_text: Union[
        Unset, "ColumnDetectedDatatypeInTextCheckSpec"
    ] = UNSET
    daily_detected_datatype_in_text_changed: Union[
        Unset, "ColumnDatatypeDetectedDatatypeInTextChangedCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_detected_datatype_in_text: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_detected_datatype_in_text, Unset):
            daily_detected_datatype_in_text = (
                self.daily_detected_datatype_in_text.to_dict()
            )

        daily_detected_datatype_in_text_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_detected_datatype_in_text_changed, Unset):
            daily_detected_datatype_in_text_changed = (
                self.daily_detected_datatype_in_text_changed.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_detected_datatype_in_text is not UNSET:
            field_dict["daily_detected_datatype_in_text"] = (
                daily_detected_datatype_in_text
            )
        if daily_detected_datatype_in_text_changed is not UNSET:
            field_dict["daily_detected_datatype_in_text_changed"] = (
                daily_detected_datatype_in_text_changed
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_datatype_daily_monitoring_checks_spec_custom_checks import (
            ColumnDatatypeDailyMonitoringChecksSpecCustomChecks,
        )
        from ..models.column_datatype_detected_datatype_in_text_changed_check_spec import (
            ColumnDatatypeDetectedDatatypeInTextChangedCheckSpec,
        )
        from ..models.column_detected_datatype_in_text_check_spec import (
            ColumnDetectedDatatypeInTextCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnDatatypeDailyMonitoringChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnDatatypeDailyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _daily_detected_datatype_in_text = d.pop(
            "daily_detected_datatype_in_text", UNSET
        )
        daily_detected_datatype_in_text: Union[
            Unset, ColumnDetectedDatatypeInTextCheckSpec
        ]
        if isinstance(_daily_detected_datatype_in_text, Unset):
            daily_detected_datatype_in_text = UNSET
        else:
            daily_detected_datatype_in_text = (
                ColumnDetectedDatatypeInTextCheckSpec.from_dict(
                    _daily_detected_datatype_in_text
                )
            )

        _daily_detected_datatype_in_text_changed = d.pop(
            "daily_detected_datatype_in_text_changed", UNSET
        )
        daily_detected_datatype_in_text_changed: Union[
            Unset, ColumnDatatypeDetectedDatatypeInTextChangedCheckSpec
        ]
        if isinstance(_daily_detected_datatype_in_text_changed, Unset):
            daily_detected_datatype_in_text_changed = UNSET
        else:
            daily_detected_datatype_in_text_changed = (
                ColumnDatatypeDetectedDatatypeInTextChangedCheckSpec.from_dict(
                    _daily_detected_datatype_in_text_changed
                )
            )

        column_datatype_daily_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            daily_detected_datatype_in_text=daily_detected_datatype_in_text,
            daily_detected_datatype_in_text_changed=daily_detected_datatype_in_text_changed,
        )

        column_datatype_daily_monitoring_checks_spec.additional_properties = d
        return column_datatype_daily_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.column_current_data_quality_status_model import (
        ColumnCurrentDataQualityStatusModel,
    )
    from ..models.column_list_model_advanced_properties import (
        ColumnListModelAdvancedProperties,
    )
    from ..models.column_type_snapshot_spec import ColumnTypeSnapshotSpec
    from ..models.delete_stored_data_queue_job_parameters import (
        DeleteStoredDataQueueJobParameters,
    )
    from ..models.physical_table_name import PhysicalTableName
    from ..models.statistics_collector_search_filters import (
        StatisticsCollectorSearchFilters,
    )


T = TypeVar("T", bound="ColumnListModel")


@_attrs_define
class ColumnListModel:
    """Column list model that returns the basic fields from a column specification, excluding nested nodes like a list of
    activated checks.

        Attributes:
            connection_name (Union[Unset, str]): Connection name.
            table (Union[Unset, PhysicalTableName]):
            column_name (Union[Unset, str]): Column name.
            labels (Union[Unset, List[str]]): List of labels applied to the table.
            sql_expression (Union[Unset, str]): SQL expression for a calculated column, or a column that applies additional
                data transformation to the original column value. The original column value is referenced by a token {column}.
            column_hash (Union[Unset, int]): Column hash that identifies the column using a unique hash code.
            disabled (Union[Unset, bool]): Disables all data quality checks on the column. Data quality checks will not be
                executed.
            id (Union[Unset, bool]): Marks columns that are part of a primary or a unique key. DQOps captures their values
                during error sampling to match invalid values to the rows in which the value was found.
            has_any_configured_checks (Union[Unset, bool]): True when the column has any checks configured (read-only).
            has_any_configured_profiling_checks (Union[Unset, bool]): True when the column has any profiling checks
                configured (read-only).
            has_any_configured_monitoring_checks (Union[Unset, bool]): True when the column has any monitoring checks
                configured (read-only).
            has_any_configured_partition_checks (Union[Unset, bool]): True when the column has any partition checks
                configured (read-only).
            type_snapshot (Union[Unset, ColumnTypeSnapshotSpec]):
            data_quality_status (Union[Unset, ColumnCurrentDataQualityStatusModel]): The column's most recent data quality
                status. It is a summary of the results of the most recently executed data quality checks on the column. Verify
                the value of the current_severity to see if there are any data quality issues on the column.
            run_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
                checks on which tables and columns should be executed.
            run_profiling_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
                identifies which checks on which tables and columns should be executed.
            run_monitoring_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
                identifies which checks on which tables and columns should be executed.
            run_partition_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
                identifies which checks on which tables and columns should be executed.
            collect_statistics_job_template (Union[Unset, StatisticsCollectorSearchFilters]):
            data_clean_job_template (Union[Unset, DeleteStoredDataQueueJobParameters]):
            advanced_properties (Union[Unset, ColumnListModelAdvancedProperties]): A dictionary of advanced properties that
                can be used for e.g. to support mapping data to data catalogs, a key/value dictionary.
            can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete the column.
            can_collect_statistics (Union[Unset, bool]): Boolean flag that decides if the current user can collect
                statistics.
            can_run_checks (Union[Unset, bool]): Boolean flag that decides if the current user can run checks.
            can_delete_data (Union[Unset, bool]): Boolean flag that decides if the current user can delete data (results).
    """

    connection_name: Union[Unset, str] = UNSET
    table: Union[Unset, "PhysicalTableName"] = UNSET
    column_name: Union[Unset, str] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    sql_expression: Union[Unset, str] = UNSET
    column_hash: Union[Unset, int] = UNSET
    disabled: Union[Unset, bool] = UNSET
    id: Union[Unset, bool] = UNSET
    has_any_configured_checks: Union[Unset, bool] = UNSET
    has_any_configured_profiling_checks: Union[Unset, bool] = UNSET
    has_any_configured_monitoring_checks: Union[Unset, bool] = UNSET
    has_any_configured_partition_checks: Union[Unset, bool] = UNSET
    type_snapshot: Union[Unset, "ColumnTypeSnapshotSpec"] = UNSET
    data_quality_status: Union[Unset, "ColumnCurrentDataQualityStatusModel"] = UNSET
    run_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_profiling_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_monitoring_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_partition_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    collect_statistics_job_template: Union[
        Unset, "StatisticsCollectorSearchFilters"
    ] = UNSET
    data_clean_job_template: Union[Unset, "DeleteStoredDataQueueJobParameters"] = UNSET
    advanced_properties: Union[Unset, "ColumnListModelAdvancedProperties"] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    can_collect_statistics: Union[Unset, bool] = UNSET
    can_run_checks: Union[Unset, bool] = UNSET
    can_delete_data: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table, Unset):
            table = self.table.to_dict()

        column_name = self.column_name
        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        sql_expression = self.sql_expression
        column_hash = self.column_hash
        disabled = self.disabled
        id = self.id
        has_any_configured_checks = self.has_any_configured_checks
        has_any_configured_profiling_checks = self.has_any_configured_profiling_checks
        has_any_configured_monitoring_checks = self.has_any_configured_monitoring_checks
        has_any_configured_partition_checks = self.has_any_configured_partition_checks
        type_snapshot: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.type_snapshot, Unset):
            type_snapshot = self.type_snapshot.to_dict()

        data_quality_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_quality_status, Unset):
            data_quality_status = self.data_quality_status.to_dict()

        run_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_checks_job_template, Unset):
            run_checks_job_template = self.run_checks_job_template.to_dict()

        run_profiling_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_profiling_checks_job_template, Unset):
            run_profiling_checks_job_template = (
                self.run_profiling_checks_job_template.to_dict()
            )

        run_monitoring_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_monitoring_checks_job_template, Unset):
            run_monitoring_checks_job_template = (
                self.run_monitoring_checks_job_template.to_dict()
            )

        run_partition_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_partition_checks_job_template, Unset):
            run_partition_checks_job_template = (
                self.run_partition_checks_job_template.to_dict()
            )

        collect_statistics_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.collect_statistics_job_template, Unset):
            collect_statistics_job_template = (
                self.collect_statistics_job_template.to_dict()
            )

        data_clean_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_clean_job_template, Unset):
            data_clean_job_template = self.data_clean_job_template.to_dict()

        advanced_properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.advanced_properties, Unset):
            advanced_properties = self.advanced_properties.to_dict()

        can_edit = self.can_edit
        can_collect_statistics = self.can_collect_statistics
        can_run_checks = self.can_run_checks
        can_delete_data = self.can_delete_data

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if table is not UNSET:
            field_dict["table"] = table
        if column_name is not UNSET:
            field_dict["column_name"] = column_name
        if labels is not UNSET:
            field_dict["labels"] = labels
        if sql_expression is not UNSET:
            field_dict["sql_expression"] = sql_expression
        if column_hash is not UNSET:
            field_dict["column_hash"] = column_hash
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if id is not UNSET:
            field_dict["id"] = id
        if has_any_configured_checks is not UNSET:
            field_dict["has_any_configured_checks"] = has_any_configured_checks
        if has_any_configured_profiling_checks is not UNSET:
            field_dict["has_any_configured_profiling_checks"] = (
                has_any_configured_profiling_checks
            )
        if has_any_configured_monitoring_checks is not UNSET:
            field_dict["has_any_configured_monitoring_checks"] = (
                has_any_configured_monitoring_checks
            )
        if has_any_configured_partition_checks is not UNSET:
            field_dict["has_any_configured_partition_checks"] = (
                has_any_configured_partition_checks
            )
        if type_snapshot is not UNSET:
            field_dict["type_snapshot"] = type_snapshot
        if data_quality_status is not UNSET:
            field_dict["data_quality_status"] = data_quality_status
        if run_checks_job_template is not UNSET:
            field_dict["run_checks_job_template"] = run_checks_job_template
        if run_profiling_checks_job_template is not UNSET:
            field_dict["run_profiling_checks_job_template"] = (
                run_profiling_checks_job_template
            )
        if run_monitoring_checks_job_template is not UNSET:
            field_dict["run_monitoring_checks_job_template"] = (
                run_monitoring_checks_job_template
            )
        if run_partition_checks_job_template is not UNSET:
            field_dict["run_partition_checks_job_template"] = (
                run_partition_checks_job_template
            )
        if collect_statistics_job_template is not UNSET:
            field_dict["collect_statistics_job_template"] = (
                collect_statistics_job_template
            )
        if data_clean_job_template is not UNSET:
            field_dict["data_clean_job_template"] = data_clean_job_template
        if advanced_properties is not UNSET:
            field_dict["advanced_properties"] = advanced_properties
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if can_collect_statistics is not UNSET:
            field_dict["can_collect_statistics"] = can_collect_statistics
        if can_run_checks is not UNSET:
            field_dict["can_run_checks"] = can_run_checks
        if can_delete_data is not UNSET:
            field_dict["can_delete_data"] = can_delete_data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.column_current_data_quality_status_model import (
            ColumnCurrentDataQualityStatusModel,
        )
        from ..models.column_list_model_advanced_properties import (
            ColumnListModelAdvancedProperties,
        )
        from ..models.column_type_snapshot_spec import ColumnTypeSnapshotSpec
        from ..models.delete_stored_data_queue_job_parameters import (
            DeleteStoredDataQueueJobParameters,
        )
        from ..models.physical_table_name import PhysicalTableName
        from ..models.statistics_collector_search_filters import (
            StatisticsCollectorSearchFilters,
        )

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        _table = d.pop("table", UNSET)
        table: Union[Unset, PhysicalTableName]
        if isinstance(_table, Unset):
            table = UNSET
        else:
            table = PhysicalTableName.from_dict(_table)

        column_name = d.pop("column_name", UNSET)

        labels = cast(List[str], d.pop("labels", UNSET))

        sql_expression = d.pop("sql_expression", UNSET)

        column_hash = d.pop("column_hash", UNSET)

        disabled = d.pop("disabled", UNSET)

        id = d.pop("id", UNSET)

        has_any_configured_checks = d.pop("has_any_configured_checks", UNSET)

        has_any_configured_profiling_checks = d.pop(
            "has_any_configured_profiling_checks", UNSET
        )

        has_any_configured_monitoring_checks = d.pop(
            "has_any_configured_monitoring_checks", UNSET
        )

        has_any_configured_partition_checks = d.pop(
            "has_any_configured_partition_checks", UNSET
        )

        _type_snapshot = d.pop("type_snapshot", UNSET)
        type_snapshot: Union[Unset, ColumnTypeSnapshotSpec]
        if isinstance(_type_snapshot, Unset):
            type_snapshot = UNSET
        else:
            type_snapshot = ColumnTypeSnapshotSpec.from_dict(_type_snapshot)

        _data_quality_status = d.pop("data_quality_status", UNSET)
        data_quality_status: Union[Unset, ColumnCurrentDataQualityStatusModel]
        if isinstance(_data_quality_status, Unset):
            data_quality_status = UNSET
        else:
            data_quality_status = ColumnCurrentDataQualityStatusModel.from_dict(
                _data_quality_status
            )

        _run_checks_job_template = d.pop("run_checks_job_template", UNSET)
        run_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_checks_job_template, Unset):
            run_checks_job_template = UNSET
        else:
            run_checks_job_template = CheckSearchFilters.from_dict(
                _run_checks_job_template
            )

        _run_profiling_checks_job_template = d.pop(
            "run_profiling_checks_job_template", UNSET
        )
        run_profiling_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_profiling_checks_job_template, Unset):
            run_profiling_checks_job_template = UNSET
        else:
            run_profiling_checks_job_template = CheckSearchFilters.from_dict(
                _run_profiling_checks_job_template
            )

        _run_monitoring_checks_job_template = d.pop(
            "run_monitoring_checks_job_template", UNSET
        )
        run_monitoring_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_monitoring_checks_job_template, Unset):
            run_monitoring_checks_job_template = UNSET
        else:
            run_monitoring_checks_job_template = CheckSearchFilters.from_dict(
                _run_monitoring_checks_job_template
            )

        _run_partition_checks_job_template = d.pop(
            "run_partition_checks_job_template", UNSET
        )
        run_partition_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_partition_checks_job_template, Unset):
            run_partition_checks_job_template = UNSET
        else:
            run_partition_checks_job_template = CheckSearchFilters.from_dict(
                _run_partition_checks_job_template
            )

        _collect_statistics_job_template = d.pop(
            "collect_statistics_job_template", UNSET
        )
        collect_statistics_job_template: Union[Unset, StatisticsCollectorSearchFilters]
        if isinstance(_collect_statistics_job_template, Unset):
            collect_statistics_job_template = UNSET
        else:
            collect_statistics_job_template = (
                StatisticsCollectorSearchFilters.from_dict(
                    _collect_statistics_job_template
                )
            )

        _data_clean_job_template = d.pop("data_clean_job_template", UNSET)
        data_clean_job_template: Union[Unset, DeleteStoredDataQueueJobParameters]
        if isinstance(_data_clean_job_template, Unset):
            data_clean_job_template = UNSET
        else:
            data_clean_job_template = DeleteStoredDataQueueJobParameters.from_dict(
                _data_clean_job_template
            )

        _advanced_properties = d.pop("advanced_properties", UNSET)
        advanced_properties: Union[Unset, ColumnListModelAdvancedProperties]
        if isinstance(_advanced_properties, Unset):
            advanced_properties = UNSET
        else:
            advanced_properties = ColumnListModelAdvancedProperties.from_dict(
                _advanced_properties
            )

        can_edit = d.pop("can_edit", UNSET)

        can_collect_statistics = d.pop("can_collect_statistics", UNSET)

        can_run_checks = d.pop("can_run_checks", UNSET)

        can_delete_data = d.pop("can_delete_data", UNSET)

        column_list_model = cls(
            connection_name=connection_name,
            table=table,
            column_name=column_name,
            labels=labels,
            sql_expression=sql_expression,
            column_hash=column_hash,
            disabled=disabled,
            id=id,
            has_any_configured_checks=has_any_configured_checks,
            has_any_configured_profiling_checks=has_any_configured_profiling_checks,
            has_any_configured_monitoring_checks=has_any_configured_monitoring_checks,
            has_any_configured_partition_checks=has_any_configured_partition_checks,
            type_snapshot=type_snapshot,
            data_quality_status=data_quality_status,
            run_checks_job_template=run_checks_job_template,
            run_profiling_checks_job_template=run_profiling_checks_job_template,
            run_monitoring_checks_job_template=run_monitoring_checks_job_template,
            run_partition_checks_job_template=run_partition_checks_job_template,
            collect_statistics_job_template=collect_statistics_job_template,
            data_clean_job_template=data_clean_job_template,
            advanced_properties=advanced_properties,
            can_edit=can_edit,
            can_collect_statistics=can_collect_statistics,
            can_run_checks=can_run_checks,
            can_delete_data=can_delete_data,
        )

        column_list_model.additional_properties = d
        return column_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.folder_synchronization_status import FolderSynchronizationStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="CloudSynchronizationFoldersStatusModel")


@_attrs_define
class CloudSynchronizationFoldersStatusModel:
    """
    Attributes:
        sources (Union[Unset, FolderSynchronizationStatus]):
        sensors (Union[Unset, FolderSynchronizationStatus]):
        rules (Union[Unset, FolderSynchronizationStatus]):
        checks (Union[Unset, FolderSynchronizationStatus]):
        settings (Union[Unset, FolderSynchronizationStatus]):
        credentials (Union[Unset, FolderSynchronizationStatus]):
        dictionaries (Union[Unset, FolderSynchronizationStatus]):
        patterns (Union[Unset, FolderSynchronizationStatus]):
        data_sensor_readouts (Union[Unset, FolderSynchronizationStatus]):
        data_check_results (Union[Unset, FolderSynchronizationStatus]):
        data_statistics (Union[Unset, FolderSynchronizationStatus]):
        data_errors (Union[Unset, FolderSynchronizationStatus]):
        data_incidents (Union[Unset, FolderSynchronizationStatus]):
    """

    sources: Union[Unset, FolderSynchronizationStatus] = UNSET
    sensors: Union[Unset, FolderSynchronizationStatus] = UNSET
    rules: Union[Unset, FolderSynchronizationStatus] = UNSET
    checks: Union[Unset, FolderSynchronizationStatus] = UNSET
    settings: Union[Unset, FolderSynchronizationStatus] = UNSET
    credentials: Union[Unset, FolderSynchronizationStatus] = UNSET
    dictionaries: Union[Unset, FolderSynchronizationStatus] = UNSET
    patterns: Union[Unset, FolderSynchronizationStatus] = UNSET
    data_sensor_readouts: Union[Unset, FolderSynchronizationStatus] = UNSET
    data_check_results: Union[Unset, FolderSynchronizationStatus] = UNSET
    data_statistics: Union[Unset, FolderSynchronizationStatus] = UNSET
    data_errors: Union[Unset, FolderSynchronizationStatus] = UNSET
    data_incidents: Union[Unset, FolderSynchronizationStatus] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sources: Union[Unset, str] = UNSET
        if not isinstance(self.sources, Unset):
            sources = self.sources.value

        sensors: Union[Unset, str] = UNSET
        if not isinstance(self.sensors, Unset):
            sensors = self.sensors.value

        rules: Union[Unset, str] = UNSET
        if not isinstance(self.rules, Unset):
            rules = self.rules.value

        checks: Union[Unset, str] = UNSET
        if not isinstance(self.checks, Unset):
            checks = self.checks.value

        settings: Union[Unset, str] = UNSET
        if not isinstance(self.settings, Unset):
            settings = self.settings.value

        credentials: Union[Unset, str] = UNSET
        if not isinstance(self.credentials, Unset):
            credentials = self.credentials.value

        dictionaries: Union[Unset, str] = UNSET
        if not isinstance(self.dictionaries, Unset):
            dictionaries = self.dictionaries.value

        patterns: Union[Unset, str] = UNSET
        if not isinstance(self.patterns, Unset):
            patterns = self.patterns.value

        data_sensor_readouts: Union[Unset, str] = UNSET
        if not isinstance(self.data_sensor_readouts, Unset):
            data_sensor_readouts = self.data_sensor_readouts.value

        data_check_results: Union[Unset, str] = UNSET
        if not isinstance(self.data_check_results, Unset):
            data_check_results = self.data_check_results.value

        data_statistics: Union[Unset, str] = UNSET
        if not isinstance(self.data_statistics, Unset):
            data_statistics = self.data_statistics.value

        data_errors: Union[Unset, str] = UNSET
        if not isinstance(self.data_errors, Unset):
            data_errors = self.data_errors.value

        data_incidents: Union[Unset, str] = UNSET
        if not isinstance(self.data_incidents, Unset):
            data_incidents = self.data_incidents.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sources is not UNSET:
            field_dict["sources"] = sources
        if sensors is not UNSET:
            field_dict["sensors"] = sensors
        if rules is not UNSET:
            field_dict["rules"] = rules
        if checks is not UNSET:
            field_dict["checks"] = checks
        if settings is not UNSET:
            field_dict["settings"] = settings
        if credentials is not UNSET:
            field_dict["credentials"] = credentials
        if dictionaries is not UNSET:
            field_dict["dictionaries"] = dictionaries
        if patterns is not UNSET:
            field_dict["patterns"] = patterns
        if data_sensor_readouts is not UNSET:
            field_dict["data_sensor_readouts"] = data_sensor_readouts
        if data_check_results is not UNSET:
            field_dict["data_check_results"] = data_check_results
        if data_statistics is not UNSET:
            field_dict["data_statistics"] = data_statistics
        if data_errors is not UNSET:
            field_dict["data_errors"] = data_errors
        if data_incidents is not UNSET:
            field_dict["data_incidents"] = data_incidents

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _sources = d.pop("sources", UNSET)
        sources: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_sources, Unset):
            sources = UNSET
        else:
            sources = FolderSynchronizationStatus(_sources)

        _sensors = d.pop("sensors", UNSET)
        sensors: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_sensors, Unset):
            sensors = UNSET
        else:
            sensors = FolderSynchronizationStatus(_sensors)

        _rules = d.pop("rules", UNSET)
        rules: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_rules, Unset):
            rules = UNSET
        else:
            rules = FolderSynchronizationStatus(_rules)

        _checks = d.pop("checks", UNSET)
        checks: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_checks, Unset):
            checks = UNSET
        else:
            checks = FolderSynchronizationStatus(_checks)

        _settings = d.pop("settings", UNSET)
        settings: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_settings, Unset):
            settings = UNSET
        else:
            settings = FolderSynchronizationStatus(_settings)

        _credentials = d.pop("credentials", UNSET)
        credentials: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_credentials, Unset):
            credentials = UNSET
        else:
            credentials = FolderSynchronizationStatus(_credentials)

        _dictionaries = d.pop("dictionaries", UNSET)
        dictionaries: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_dictionaries, Unset):
            dictionaries = UNSET
        else:
            dictionaries = FolderSynchronizationStatus(_dictionaries)

        _patterns = d.pop("patterns", UNSET)
        patterns: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_patterns, Unset):
            patterns = UNSET
        else:
            patterns = FolderSynchronizationStatus(_patterns)

        _data_sensor_readouts = d.pop("data_sensor_readouts", UNSET)
        data_sensor_readouts: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_data_sensor_readouts, Unset):
            data_sensor_readouts = UNSET
        else:
            data_sensor_readouts = FolderSynchronizationStatus(_data_sensor_readouts)

        _data_check_results = d.pop("data_check_results", UNSET)
        data_check_results: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_data_check_results, Unset):
            data_check_results = UNSET
        else:
            data_check_results = FolderSynchronizationStatus(_data_check_results)

        _data_statistics = d.pop("data_statistics", UNSET)
        data_statistics: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_data_statistics, Unset):
            data_statistics = UNSET
        else:
            data_statistics = FolderSynchronizationStatus(_data_statistics)

        _data_errors = d.pop("data_errors", UNSET)
        data_errors: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_data_errors, Unset):
            data_errors = UNSET
        else:
            data_errors = FolderSynchronizationStatus(_data_errors)

        _data_incidents = d.pop("data_incidents", UNSET)
        data_incidents: Union[Unset, FolderSynchronizationStatus]
        if isinstance(_data_incidents, Unset):
            data_incidents = UNSET
        else:
            data_incidents = FolderSynchronizationStatus(_data_incidents)

        cloud_synchronization_folders_status_model = cls(
            sources=sources,
            sensors=sensors,
            rules=rules,
            checks=checks,
            settings=settings,
            credentials=credentials,
            dictionaries=dictionaries,
            patterns=patterns,
            data_sensor_readouts=data_sensor_readouts,
            data_check_results=data_check_results,
            data_statistics=data_statistics,
            data_errors=data_errors,
            data_incidents=data_incidents,
        )

        cloud_synchronization_folders_status_model.additional_properties = d
        return cloud_synchronization_folders_status_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.table_comparison_column_results_model import (
        TableComparisonColumnResultsModel,
    )


T = TypeVar("T", bound="TableComparisonResultsModelColumnComparisonResults")


@_attrs_define
class TableComparisonResultsModelColumnComparisonResults:
    """The dictionary of comparison results between the tables for each compared column. The keys for the dictionary are
    the column names. The values are dictionaries of the data quality check names and their results.

    """

    additional_properties: Dict[str, "TableComparisonColumnResultsModel"] = (
        _attrs_field(init=False, factory=dict)
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_comparison_column_results_model import (
            TableComparisonColumnResultsModel,
        )

        d = src_dict.copy()
        table_comparison_results_model_column_comparison_results = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = TableComparisonColumnResultsModel.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        table_comparison_results_model_column_comparison_results.additional_properties = (
            additional_properties
        )
        return table_comparison_results_model_column_comparison_results

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "TableComparisonColumnResultsModel":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "TableComparisonColumnResultsModel") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.target_rule_severity_level import TargetRuleSeverityLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckMiningParametersModel")


@_attrs_define
class CheckMiningParametersModel:
    """Data quality check rule mining parameters. Configure what type of checks should be configured.

    Attributes:
        severity_level (Union[Unset, TargetRuleSeverityLevel]):
        category_filter (Union[Unset, str]): Optional filter for the check category names, supports filtering with
            prefixes and suffixes defined as a '*' character.
        check_name_filter (Union[Unset, str]): Optional filter for the check names, supports filtering with prefixes and
            suffixes defined as a '*' character.
        column_name_filter (Union[Unset, str]): Optional filter for the column names, supports filtering with prefixes
            and suffixes defined as a '*' character.
        copy_failed_profiling_checks (Union[Unset, bool]): Copy also the configuration of profiling checks that failed.
        copy_disabled_profiling_checks (Union[Unset, bool]): Copy also the configuration of profiling checks that are
            disabled.
        copy_profiling_checks (Union[Unset, bool]): Copy the configuration of valid profiling checks.
        reconfigure_policy_enabled_checks (Union[Unset, bool]): Propose the rules for default checks that were activated
            using data quality check patterns (policies). The default value of this parameter is 'true'.
        propose_checks_from_statistics (Union[Unset, bool]): Propose the configuration of data quality checks from
            statistics.
        propose_minimum_row_count (Union[Unset, bool]): Propose the default configuration of the minimum row count for
            monitoring checks (full table scans). The default value of this parameter is 'true'.
        propose_column_count (Union[Unset, bool]): Propose the default configuration of the column count check. The
            default value of this parameter is 'true'.
        propose_timeliness_checks (Union[Unset, bool]): Propose the default configuration of the timeliness checks,
            including an accepted freshness delay. The default value of this parameter is 'true'.
        propose_nulls_checks (Union[Unset, bool]): Propose the default configuration the null checks that verify that
            there are no null values. The default value of this parameter is 'true'.
        propose_not_nulls_checks (Union[Unset, bool]): Propose the default configuration the not-null checks that
            validate scale of not-nulls (require a mix of some not-null and null values).The default value of this parameter
            is 'false'.
        propose_text_values_data_type (Union[Unset, bool]): Propose the default configuration the detected data type of
            values in a text column check, when text columns contain an uniform type such as integers or dates. The default
            value of this parameter is 'true'.
        propose_column_exists (Union[Unset, bool]): Enables a rule on the column's schema check that verifies if the
            column exists. It is enabled on columns that were detected as existing during data profiling. The default value
            of this parameter is 'true'.
        propose_uniqueness_checks (Union[Unset, bool]): Propose the default configuration the uniqueness checks that
            validate the number of distinct and duplicate values. The default value of this parameter is 'true'.
        propose_numeric_ranges (Union[Unset, bool]): Propose the default configuration of numeric checks that validate
            the ranges of numeric values, and aggregated measures such as minimum, maximum, mean and sum of values. The
            default value of this parameter is 'true'.
        propose_percentile_ranges (Union[Unset, bool]): Propose the default configuration of the median and percentile
            in range checks that validate the value at a given percentile, such as a value in middle of all column values.
            The default value of this parameter is 'false' because calculating the median requires running a separate query
            on the data source, which is not advisable for data observability.
        propose_text_length_ranges (Union[Unset, bool]): Propose the default configuration of the text length checks.
            The default value of this parameter is 'true'.
        propose_word_count_ranges (Union[Unset, bool]): Propose the default configuration of the minimum and maximum
            word count of text columns. The default value of this parameter is 'true'.
        propose_values_in_set_checks (Union[Unset, bool]): Propose the configuration the categorical values checks from
            the accepted values category. These checks will be configured to ensure that the column contains only sample
            values that were identified during data profiling. The default value of this parameter is 'true'.
        values_in_set_treat_rare_values_as_invalid (Union[Unset, bool]): Configure the values in set checks from the
            accepted values category to raise data quality issues for rare values. DQOps will not add rare categorical
            values to the list of expected values. The default value of this parameter is 'true'.
        propose_top_values_checks (Union[Unset, bool]): Propose the configuration the text values in the top values
            checks from the accepted values category. These checks find the most common values in a table and ensure that
            they are the same values that were identified during data profiling. The default value of this parameter is
            'true'.
        propose_text_conversion_checks (Union[Unset, bool]): Propose the configuration the data type conversion checks
            that verify if text values can be converted to more specific data types such as boolean, date, float or integer.
            This type of checks are used to verify raw tables in the landing zones. The default value of this parameter is
            'true'.
        propose_bool_percent_checks (Union[Unset, bool]): Propose the default configuration for the checks that measure
            the percentage of boolean values. The default value of this parameter is 'true'.
        propose_date_checks (Union[Unset, bool]): Propose the default configuration for the date and datetime checks
            that detect invalid dates. The default value of this parameter is 'true'.
        propose_standard_pattern_checks (Union[Unset, bool]): Propose the default configuration for the patterns check
            that validate the format of popular text patterns, such as UUIDs, phone numbers, or emails. DQOps will configure
            these data quality checks when analyzed columns contain enough values matching a standard pattern. The default
            value of this parameter is 'true'.
        detect_regular_expressions (Union[Unset, bool]): Analyze sample text values and try to find a regular expression
            that detects valid values similar to the sample values. The default value of this parameter is 'true'.
        propose_whitespace_checks (Union[Unset, bool]): Propose the default configuration for the whitespace detection
            checks. Whitespace checks detect common data quality issues with storing text representations of null values,
            such as 'null', 'None', 'n/a' and other texts that should be stored as regular NULL values. The default value of
            this parameter is 'true'.
        apply_pii_checks (Union[Unset, bool]): Applies rules to Personal Identifiable Information checks (sensitive
            data), but only when the checks were activated manually as profiling checks, or through a data quality check
            pattern that scans all columns for PII data. The default value of this parameter is 'true'.
        propose_custom_checks (Union[Unset, bool]): Propose the default configuration for custom checks that use built-
            in data quality rules. The default value of this parameter is 'true'.
        fail_checks_at_percent_error_rows (Union[Unset, float]): The percentage value captured by a profiling check (for
            example 0.03% of errors or 99.97% of valid) that is used to propose a percentage rule that will treat the values
            as errors (i.e., max_percent = 0%, or min_percent = 100%).
        max_percent_error_rows_for_percent_checks (Union[Unset, float]): The default maximum percentage of invalid rows
            for which the rule engine should configure rule values, especially min_percent, min_count or max_percent.
    """

    severity_level: Union[Unset, TargetRuleSeverityLevel] = UNSET
    category_filter: Union[Unset, str] = UNSET
    check_name_filter: Union[Unset, str] = UNSET
    column_name_filter: Union[Unset, str] = UNSET
    copy_failed_profiling_checks: Union[Unset, bool] = UNSET
    copy_disabled_profiling_checks: Union[Unset, bool] = UNSET
    copy_profiling_checks: Union[Unset, bool] = UNSET
    reconfigure_policy_enabled_checks: Union[Unset, bool] = UNSET
    propose_checks_from_statistics: Union[Unset, bool] = UNSET
    propose_minimum_row_count: Union[Unset, bool] = UNSET
    propose_column_count: Union[Unset, bool] = UNSET
    propose_timeliness_checks: Union[Unset, bool] = UNSET
    propose_nulls_checks: Union[Unset, bool] = UNSET
    propose_not_nulls_checks: Union[Unset, bool] = UNSET
    propose_text_values_data_type: Union[Unset, bool] = UNSET
    propose_column_exists: Union[Unset, bool] = UNSET
    propose_uniqueness_checks: Union[Unset, bool] = UNSET
    propose_numeric_ranges: Union[Unset, bool] = UNSET
    propose_percentile_ranges: Union[Unset, bool] = UNSET
    propose_text_length_ranges: Union[Unset, bool] = UNSET
    propose_word_count_ranges: Union[Unset, bool] = UNSET
    propose_values_in_set_checks: Union[Unset, bool] = UNSET
    values_in_set_treat_rare_values_as_invalid: Union[Unset, bool] = UNSET
    propose_top_values_checks: Union[Unset, bool] = UNSET
    propose_text_conversion_checks: Union[Unset, bool] = UNSET
    propose_bool_percent_checks: Union[Unset, bool] = UNSET
    propose_date_checks: Union[Unset, bool] = UNSET
    propose_standard_pattern_checks: Union[Unset, bool] = UNSET
    detect_regular_expressions: Union[Unset, bool] = UNSET
    propose_whitespace_checks: Union[Unset, bool] = UNSET
    apply_pii_checks: Union[Unset, bool] = UNSET
    propose_custom_checks: Union[Unset, bool] = UNSET
    fail_checks_at_percent_error_rows: Union[Unset, float] = UNSET
    max_percent_error_rows_for_percent_checks: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        severity_level: Union[Unset, str] = UNSET
        if not isinstance(self.severity_level, Unset):
            severity_level = self.severity_level.value

        category_filter = self.category_filter
        check_name_filter = self.check_name_filter
        column_name_filter = self.column_name_filter
        copy_failed_profiling_checks = self.copy_failed_profiling_checks
        copy_disabled_profiling_checks = self.copy_disabled_profiling_checks
        copy_profiling_checks = self.copy_profiling_checks
        reconfigure_policy_enabled_checks = self.reconfigure_policy_enabled_checks
        propose_checks_from_statistics = self.propose_checks_from_statistics
        propose_minimum_row_count = self.propose_minimum_row_count
        propose_column_count = self.propose_column_count
        propose_timeliness_checks = self.propose_timeliness_checks
        propose_nulls_checks = self.propose_nulls_checks
        propose_not_nulls_checks = self.propose_not_nulls_checks
        propose_text_values_data_type = self.propose_text_values_data_type
        propose_column_exists = self.propose_column_exists
        propose_uniqueness_checks = self.propose_uniqueness_checks
        propose_numeric_ranges = self.propose_numeric_ranges
        propose_percentile_ranges = self.propose_percentile_ranges
        propose_text_length_ranges = self.propose_text_length_ranges
        propose_word_count_ranges = self.propose_word_count_ranges
        propose_values_in_set_checks = self.propose_values_in_set_checks
        values_in_set_treat_rare_values_as_invalid = (
            self.values_in_set_treat_rare_values_as_invalid
        )
        propose_top_values_checks = self.propose_top_values_checks
        propose_text_conversion_checks = self.propose_text_conversion_checks
        propose_bool_percent_checks = self.propose_bool_percent_checks
        propose_date_checks = self.propose_date_checks
        propose_standard_pattern_checks = self.propose_standard_pattern_checks
        detect_regular_expressions = self.detect_regular_expressions
        propose_whitespace_checks = self.propose_whitespace_checks
        apply_pii_checks = self.apply_pii_checks
        propose_custom_checks = self.propose_custom_checks
        fail_checks_at_percent_error_rows = self.fail_checks_at_percent_error_rows
        max_percent_error_rows_for_percent_checks = (
            self.max_percent_error_rows_for_percent_checks
        )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if severity_level is not UNSET:
            field_dict["severity_level"] = severity_level
        if category_filter is not UNSET:
            field_dict["category_filter"] = category_filter
        if check_name_filter is not UNSET:
            field_dict["check_name_filter"] = check_name_filter
        if column_name_filter is not UNSET:
            field_dict["column_name_filter"] = column_name_filter
        if copy_failed_profiling_checks is not UNSET:
            field_dict["copy_failed_profiling_checks"] = copy_failed_profiling_checks
        if copy_disabled_profiling_checks is not UNSET:
            field_dict["copy_disabled_profiling_checks"] = (
                copy_disabled_profiling_checks
            )
        if copy_profiling_checks is not UNSET:
            field_dict["copy_profiling_checks"] = copy_profiling_checks
        if reconfigure_policy_enabled_checks is not UNSET:
            field_dict["reconfigure_policy_enabled_checks"] = (
                reconfigure_policy_enabled_checks
            )
        if propose_checks_from_statistics is not UNSET:
            field_dict["propose_checks_from_statistics"] = (
                propose_checks_from_statistics
            )
        if propose_minimum_row_count is not UNSET:
            field_dict["propose_minimum_row_count"] = propose_minimum_row_count
        if propose_column_count is not UNSET:
            field_dict["propose_column_count"] = propose_column_count
        if propose_timeliness_checks is not UNSET:
            field_dict["propose_timeliness_checks"] = propose_timeliness_checks
        if propose_nulls_checks is not UNSET:
            field_dict["propose_nulls_checks"] = propose_nulls_checks
        if propose_not_nulls_checks is not UNSET:
            field_dict["propose_not_nulls_checks"] = propose_not_nulls_checks
        if propose_text_values_data_type is not UNSET:
            field_dict["propose_text_values_data_type"] = propose_text_values_data_type
        if propose_column_exists is not UNSET:
            field_dict["propose_column_exists"] = propose_column_exists
        if propose_uniqueness_checks is not UNSET:
            field_dict["propose_uniqueness_checks"] = propose_uniqueness_checks
        if propose_numeric_ranges is not UNSET:
            field_dict["propose_numeric_ranges"] = propose_numeric_ranges
        if propose_percentile_ranges is not UNSET:
            field_dict["propose_percentile_ranges"] = propose_percentile_ranges
        if propose_text_length_ranges is not UNSET:
            field_dict["propose_text_length_ranges"] = propose_text_length_ranges
        if propose_word_count_ranges is not UNSET:
            field_dict["propose_word_count_ranges"] = propose_word_count_ranges
        if propose_values_in_set_checks is not UNSET:
            field_dict["propose_values_in_set_checks"] = propose_values_in_set_checks
        if values_in_set_treat_rare_values_as_invalid is not UNSET:
            field_dict["values_in_set_treat_rare_values_as_invalid"] = (
                values_in_set_treat_rare_values_as_invalid
            )
        if propose_top_values_checks is not UNSET:
            field_dict["propose_top_values_checks"] = propose_top_values_checks
        if propose_text_conversion_checks is not UNSET:
            field_dict["propose_text_conversion_checks"] = (
                propose_text_conversion_checks
            )
        if propose_bool_percent_checks is not UNSET:
            field_dict["propose_bool_percent_checks"] = propose_bool_percent_checks
        if propose_date_checks is not UNSET:
            field_dict["propose_date_checks"] = propose_date_checks
        if propose_standard_pattern_checks is not UNSET:
            field_dict["propose_standard_pattern_checks"] = (
                propose_standard_pattern_checks
            )
        if detect_regular_expressions is not UNSET:
            field_dict["detect_regular_expressions"] = detect_regular_expressions
        if propose_whitespace_checks is not UNSET:
            field_dict["propose_whitespace_checks"] = propose_whitespace_checks
        if apply_pii_checks is not UNSET:
            field_dict["apply_pii_checks"] = apply_pii_checks
        if propose_custom_checks is not UNSET:
            field_dict["propose_custom_checks"] = propose_custom_checks
        if fail_checks_at_percent_error_rows is not UNSET:
            field_dict["fail_checks_at_percent_error_rows"] = (
                fail_checks_at_percent_error_rows
            )
        if max_percent_error_rows_for_percent_checks is not UNSET:
            field_dict["max_percent_error_rows_for_percent_checks"] = (
                max_percent_error_rows_for_percent_checks
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _severity_level = d.pop("severity_level", UNSET)
        severity_level: Union[Unset, TargetRuleSeverityLevel]
        if isinstance(_severity_level, Unset):
            severity_level = UNSET
        else:
            severity_level = TargetRuleSeverityLevel(_severity_level)

        category_filter = d.pop("category_filter", UNSET)

        check_name_filter = d.pop("check_name_filter", UNSET)

        column_name_filter = d.pop("column_name_filter", UNSET)

        copy_failed_profiling_checks = d.pop("copy_failed_profiling_checks", UNSET)

        copy_disabled_profiling_checks = d.pop("copy_disabled_profiling_checks", UNSET)

        copy_profiling_checks = d.pop("copy_profiling_checks", UNSET)

        reconfigure_policy_enabled_checks = d.pop(
            "reconfigure_policy_enabled_checks", UNSET
        )

        propose_checks_from_statistics = d.pop("propose_checks_from_statistics", UNSET)

        propose_minimum_row_count = d.pop("propose_minimum_row_count", UNSET)

        propose_column_count = d.pop("propose_column_count", UNSET)

        propose_timeliness_checks = d.pop("propose_timeliness_checks", UNSET)

        propose_nulls_checks = d.pop("propose_nulls_checks", UNSET)

        propose_not_nulls_checks = d.pop("propose_not_nulls_checks", UNSET)

        propose_text_values_data_type = d.pop("propose_text_values_data_type", UNSET)

        propose_column_exists = d.pop("propose_column_exists", UNSET)

        propose_uniqueness_checks = d.pop("propose_uniqueness_checks", UNSET)

        propose_numeric_ranges = d.pop("propose_numeric_ranges", UNSET)

        propose_percentile_ranges = d.pop("propose_percentile_ranges", UNSET)

        propose_text_length_ranges = d.pop("propose_text_length_ranges", UNSET)

        propose_word_count_ranges = d.pop("propose_word_count_ranges", UNSET)

        propose_values_in_set_checks = d.pop("propose_values_in_set_checks", UNSET)

        values_in_set_treat_rare_values_as_invalid = d.pop(
            "values_in_set_treat_rare_values_as_invalid", UNSET
        )

        propose_top_values_checks = d.pop("propose_top_values_checks", UNSET)

        propose_text_conversion_checks = d.pop("propose_text_conversion_checks", UNSET)

        propose_bool_percent_checks = d.pop("propose_bool_percent_checks", UNSET)

        propose_date_checks = d.pop("propose_date_checks", UNSET)

        propose_standard_pattern_checks = d.pop(
            "propose_standard_pattern_checks", UNSET
        )

        detect_regular_expressions = d.pop("detect_regular_expressions", UNSET)

        propose_whitespace_checks = d.pop("propose_whitespace_checks", UNSET)

        apply_pii_checks = d.pop("apply_pii_checks", UNSET)

        propose_custom_checks = d.pop("propose_custom_checks", UNSET)

        fail_checks_at_percent_error_rows = d.pop(
            "fail_checks_at_percent_error_rows", UNSET
        )

        max_percent_error_rows_for_percent_checks = d.pop(
            "max_percent_error_rows_for_percent_checks", UNSET
        )

        check_mining_parameters_model = cls(
            severity_level=severity_level,
            category_filter=category_filter,
            check_name_filter=check_name_filter,
            column_name_filter=column_name_filter,
            copy_failed_profiling_checks=copy_failed_profiling_checks,
            copy_disabled_profiling_checks=copy_disabled_profiling_checks,
            copy_profiling_checks=copy_profiling_checks,
            reconfigure_policy_enabled_checks=reconfigure_policy_enabled_checks,
            propose_checks_from_statistics=propose_checks_from_statistics,
            propose_minimum_row_count=propose_minimum_row_count,
            propose_column_count=propose_column_count,
            propose_timeliness_checks=propose_timeliness_checks,
            propose_nulls_checks=propose_nulls_checks,
            propose_not_nulls_checks=propose_not_nulls_checks,
            propose_text_values_data_type=propose_text_values_data_type,
            propose_column_exists=propose_column_exists,
            propose_uniqueness_checks=propose_uniqueness_checks,
            propose_numeric_ranges=propose_numeric_ranges,
            propose_percentile_ranges=propose_percentile_ranges,
            propose_text_length_ranges=propose_text_length_ranges,
            propose_word_count_ranges=propose_word_count_ranges,
            propose_values_in_set_checks=propose_values_in_set_checks,
            values_in_set_treat_rare_values_as_invalid=values_in_set_treat_rare_values_as_invalid,
            propose_top_values_checks=propose_top_values_checks,
            propose_text_conversion_checks=propose_text_conversion_checks,
            propose_bool_percent_checks=propose_bool_percent_checks,
            propose_date_checks=propose_date_checks,
            propose_standard_pattern_checks=propose_standard_pattern_checks,
            detect_regular_expressions=detect_regular_expressions,
            propose_whitespace_checks=propose_whitespace_checks,
            apply_pii_checks=apply_pii_checks,
            propose_custom_checks=propose_custom_checks,
            fail_checks_at_percent_error_rows=fail_checks_at_percent_error_rows,
            max_percent_error_rows_for_percent_checks=max_percent_error_rows_for_percent_checks,
        )

        check_mining_parameters_model.additional_properties = d
        return check_mining_parameters_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.default_rule_severity_level import DefaultRuleSeverityLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckDefinitionModel")


@_attrs_define
class CheckDefinitionModel:
    """Data quality check definition model

    Attributes:
        check_name (Union[Unset, str]): Check name
        sensor_name (Union[Unset, str]): Sensor name
        rule_name (Union[Unset, str]): Rule name
        help_text (Union[Unset, str]): Help text that is shown in the check editor that describes the purpose and usage
            of the check
        friendly_name (Union[Unset, str]): An alternative check's name that is shown on the check editor.
        standard (Union[Unset, bool]): This is a standard data quality check that is always shown on the data quality
            checks editor screen. Non-standard data quality checks (when the value is false) are advanced checks that are
            shown when the user decides to expand the list of checks.
        default_severity (Union[Unset, DefaultRuleSeverityLevel]):
        custom (Union[Unset, bool]): This check has is a custom check or was customized by the user.
        built_in (Union[Unset, bool]): This check is provided with DQOps as a built-in check.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    check_name: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    rule_name: Union[Unset, str] = UNSET
    help_text: Union[Unset, str] = UNSET
    friendly_name: Union[Unset, str] = UNSET
    standard: Union[Unset, bool] = UNSET
    default_severity: Union[Unset, DefaultRuleSeverityLevel] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_name = self.check_name
        sensor_name = self.sensor_name
        rule_name = self.rule_name
        help_text = self.help_text
        friendly_name = self.friendly_name
        standard = self.standard
        default_severity: Union[Unset, str] = UNSET
        if not isinstance(self.default_severity, Unset):
            default_severity = self.default_severity.value

        custom = self.custom
        built_in = self.built_in
        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_name is not UNSET:
            field_dict["check_name"] = check_name
        if sensor_name is not UNSET:
            field_dict["sensor_name"] = sensor_name
        if rule_name is not UNSET:
            field_dict["rule_name"] = rule_name
        if help_text is not UNSET:
            field_dict["help_text"] = help_text
        if friendly_name is not UNSET:
            field_dict["friendly_name"] = friendly_name
        if standard is not UNSET:
            field_dict["standard"] = standard
        if default_severity is not UNSET:
            field_dict["default_severity"] = default_severity
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        check_name = d.pop("check_name", UNSET)

        sensor_name = d.pop("sensor_name", UNSET)

        rule_name = d.pop("rule_name", UNSET)

        help_text = d.pop("help_text", UNSET)

        friendly_name = d.pop("friendly_name", UNSET)

        standard = d.pop("standard", UNSET)

        _default_severity = d.pop("default_severity", UNSET)
        default_severity: Union[Unset, DefaultRuleSeverityLevel]
        if isinstance(_default_severity, Unset):
            default_severity = UNSET
        else:
            default_severity = DefaultRuleSeverityLevel(_default_severity)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        check_definition_model = cls(
            check_name=check_name,
            sensor_name=sensor_name,
            rule_name=rule_name,
            help_text=help_text,
            friendly_name=friendly_name,
            standard=standard,
            default_severity=default_severity,
            custom=custom,
            built_in=built_in,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        check_definition_model.additional_properties = d
        return check_definition_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="DqoQueueJobId")


@_attrs_define
class DqoQueueJobId:
    """Identifies a single job that was pushed to the job queue.

    Attributes:
        job_id (Union[Unset, int]): Job id.
        job_business_key (Union[Unset, str]): Optional job business key that was assigned to the job. A business key is
            an alternative user assigned unique job identifier used to find the status of a job finding it by the business
            key.
        parent_job_id (Union[Unset, DqoQueueJobId]): Identifies a single job that was pushed to the job queue.
        created_at (Union[Unset, int]): The timestamp when the job was created.
    """

    job_id: Union[Unset, int] = UNSET
    job_business_key: Union[Unset, str] = UNSET
    parent_job_id: Union[Unset, "DqoQueueJobId"] = UNSET
    created_at: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        job_id = self.job_id
        job_business_key = self.job_business_key
        parent_job_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parent_job_id, Unset):
            parent_job_id = self.parent_job_id.to_dict()

        created_at = self.created_at

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if job_id is not UNSET:
            field_dict["jobId"] = job_id
        if job_business_key is not UNSET:
            field_dict["jobBusinessKey"] = job_business_key
        if parent_job_id is not UNSET:
            field_dict["parentJobId"] = parent_job_id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        job_id = d.pop("jobId", UNSET)

        job_business_key = d.pop("jobBusinessKey", UNSET)

        _parent_job_id = d.pop("parentJobId", UNSET)
        parent_job_id: Union[Unset, DqoQueueJobId]
        if isinstance(_parent_job_id, Unset):
            parent_job_id = UNSET
        else:
            parent_job_id = DqoQueueJobId.from_dict(_parent_job_id)

        created_at = d.pop("createdAt", UNSET)

        dqo_queue_job_id = cls(
            job_id=job_id,
            job_business_key=job_business_key,
            parent_job_id=parent_job_id,
            created_at=created_at,
        )

        dqo_queue_job_id.additional_properties = d
        return dqo_queue_job_id

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_custom_sql_daily_monitoring_checks_spec_custom_checks import (
        TableCustomSqlDailyMonitoringChecksSpecCustomChecks,
    )
    from ..models.table_sql_aggregate_expression_check_spec import (
        TableSqlAggregateExpressionCheckSpec,
    )
    from ..models.table_sql_condition_failed_check_spec import (
        TableSqlConditionFailedCheckSpec,
    )
    from ..models.table_sql_condition_passed_percent_check_spec import (
        TableSqlConditionPassedPercentCheckSpec,
    )
    from ..models.table_sql_import_custom_result_check_spec import (
        TableSqlImportCustomResultCheckSpec,
    )
    from ..models.table_sql_invalid_record_count_check_spec import (
        TableSqlInvalidRecordCountCheckSpec,
    )


T = TypeVar("T", bound="TableCustomSqlDailyMonitoringChecksSpec")


@_attrs_define
class TableCustomSqlDailyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableCustomSqlDailyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        daily_sql_condition_failed_on_table (Union[Unset, TableSqlConditionFailedCheckSpec]):
        daily_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
        daily_sql_aggregate_expression_on_table (Union[Unset, TableSqlAggregateExpressionCheckSpec]):
        daily_sql_invalid_record_count_on_table (Union[Unset, TableSqlInvalidRecordCountCheckSpec]):
        daily_import_custom_result_on_table (Union[Unset, TableSqlImportCustomResultCheckSpec]):
    """

    custom_checks: Union[
        Unset, "TableCustomSqlDailyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    daily_sql_condition_failed_on_table: Union[
        Unset, "TableSqlConditionFailedCheckSpec"
    ] = UNSET
    daily_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    daily_sql_aggregate_expression_on_table: Union[
        Unset, "TableSqlAggregateExpressionCheckSpec"
    ] = UNSET
    daily_sql_invalid_record_count_on_table: Union[
        Unset, "TableSqlInvalidRecordCountCheckSpec"
    ] = UNSET
    daily_import_custom_result_on_table: Union[
        Unset, "TableSqlImportCustomResultCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_sql_condition_failed_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sql_condition_failed_on_table, Unset):
            daily_sql_condition_failed_on_table = (
                self.daily_sql_condition_failed_on_table.to_dict()
            )

        daily_sql_condition_passed_percent_on_table: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.daily_sql_condition_passed_percent_on_table, Unset):
            daily_sql_condition_passed_percent_on_table = (
                self.daily_sql_condition_passed_percent_on_table.to_dict()
            )

        daily_sql_aggregate_expression_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sql_aggregate_expression_on_table, Unset):
            daily_sql_aggregate_expression_on_table = (
                self.daily_sql_aggregate_expression_on_table.to_dict()
            )

        daily_sql_invalid_record_count_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sql_invalid_record_count_on_table, Unset):
            daily_sql_invalid_record_count_on_table = (
                self.daily_sql_invalid_record_count_on_table.to_dict()
            )

        daily_import_custom_result_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_import_custom_result_on_table, Unset):
            daily_import_custom_result_on_table = (
                self.daily_import_custom_result_on_table.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_sql_condition_failed_on_table is not UNSET:
            field_dict["daily_sql_condition_failed_on_table"] = (
                daily_sql_condition_failed_on_table
            )
        if daily_sql_condition_passed_percent_on_table is not UNSET:
            field_dict["daily_sql_condition_passed_percent_on_table"] = (
                daily_sql_condition_passed_percent_on_table
            )
        if daily_sql_aggregate_expression_on_table is not UNSET:
            field_dict["daily_sql_aggregate_expression_on_table"] = (
                daily_sql_aggregate_expression_on_table
            )
        if daily_sql_invalid_record_count_on_table is not UNSET:
            field_dict["daily_sql_invalid_record_count_on_table"] = (
                daily_sql_invalid_record_count_on_table
            )
        if daily_import_custom_result_on_table is not UNSET:
            field_dict["daily_import_custom_result_on_table"] = (
                daily_import_custom_result_on_table
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_custom_sql_daily_monitoring_checks_spec_custom_checks import (
            TableCustomSqlDailyMonitoringChecksSpecCustomChecks,
        )
        from ..models.table_sql_aggregate_expression_check_spec import (
            TableSqlAggregateExpressionCheckSpec,
        )
        from ..models.table_sql_condition_failed_check_spec import (
            TableSqlConditionFailedCheckSpec,
        )
        from ..models.table_sql_condition_passed_percent_check_spec import (
            TableSqlConditionPassedPercentCheckSpec,
        )
        from ..models.table_sql_import_custom_result_check_spec import (
            TableSqlImportCustomResultCheckSpec,
        )
        from ..models.table_sql_invalid_record_count_check_spec import (
            TableSqlInvalidRecordCountCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, TableCustomSqlDailyMonitoringChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                TableCustomSqlDailyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _daily_sql_condition_failed_on_table = d.pop(
            "daily_sql_condition_failed_on_table", UNSET
        )
        daily_sql_condition_failed_on_table: Union[
            Unset, TableSqlConditionFailedCheckSpec
        ]
        if isinstance(_daily_sql_condition_failed_on_table, Unset):
            daily_sql_condition_failed_on_table = UNSET
        else:
            daily_sql_condition_failed_on_table = (
                TableSqlConditionFailedCheckSpec.from_dict(
                    _daily_sql_condition_failed_on_table
                )
            )

        _daily_sql_condition_passed_percent_on_table = d.pop(
            "daily_sql_condition_passed_percent_on_table", UNSET
        )
        daily_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_daily_sql_condition_passed_percent_on_table, Unset):
            daily_sql_condition_passed_percent_on_table = UNSET
        else:
            daily_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _daily_sql_condition_passed_percent_on_table
                )
            )

        _daily_sql_aggregate_expression_on_table = d.pop(
            "daily_sql_aggregate_expression_on_table", UNSET
        )
        daily_sql_aggregate_expression_on_table: Union[
            Unset, TableSqlAggregateExpressionCheckSpec
        ]
        if isinstance(_daily_sql_aggregate_expression_on_table, Unset):
            daily_sql_aggregate_expression_on_table = UNSET
        else:
            daily_sql_aggregate_expression_on_table = (
                TableSqlAggregateExpressionCheckSpec.from_dict(
                    _daily_sql_aggregate_expression_on_table
                )
            )

        _daily_sql_invalid_record_count_on_table = d.pop(
            "daily_sql_invalid_record_count_on_table", UNSET
        )
        daily_sql_invalid_record_count_on_table: Union[
            Unset, TableSqlInvalidRecordCountCheckSpec
        ]
        if isinstance(_daily_sql_invalid_record_count_on_table, Unset):
            daily_sql_invalid_record_count_on_table = UNSET
        else:
            daily_sql_invalid_record_count_on_table = (
                TableSqlInvalidRecordCountCheckSpec.from_dict(
                    _daily_sql_invalid_record_count_on_table
                )
            )

        _daily_import_custom_result_on_table = d.pop(
            "daily_import_custom_result_on_table", UNSET
        )
        daily_import_custom_result_on_table: Union[
            Unset, TableSqlImportCustomResultCheckSpec
        ]
        if isinstance(_daily_import_custom_result_on_table, Unset):
            daily_import_custom_result_on_table = UNSET
        else:
            daily_import_custom_result_on_table = (
                TableSqlImportCustomResultCheckSpec.from_dict(
                    _daily_import_custom_result_on_table
                )
            )

        table_custom_sql_daily_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            daily_sql_condition_failed_on_table=daily_sql_condition_failed_on_table,
            daily_sql_condition_passed_percent_on_table=daily_sql_condition_passed_percent_on_table,
            daily_sql_aggregate_expression_on_table=daily_sql_aggregate_expression_on_table,
            daily_sql_invalid_record_count_on_table=daily_sql_invalid_record_count_on_table,
            daily_import_custom_result_on_table=daily_import_custom_result_on_table,
        )

        table_custom_sql_daily_monitoring_checks_spec.additional_properties = d
        return table_custom_sql_daily_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.data_grouping_dimension_spec import DataGroupingDimensionSpec


T = TypeVar("T", bound="DataGroupingConfigurationSpec")


@_attrs_define
class DataGroupingConfigurationSpec:
    """
    Attributes:
        level_1 (Union[Unset, DataGroupingDimensionSpec]):
        level_2 (Union[Unset, DataGroupingDimensionSpec]):
        level_3 (Union[Unset, DataGroupingDimensionSpec]):
        level_4 (Union[Unset, DataGroupingDimensionSpec]):
        level_5 (Union[Unset, DataGroupingDimensionSpec]):
        level_6 (Union[Unset, DataGroupingDimensionSpec]):
        level_7 (Union[Unset, DataGroupingDimensionSpec]):
        level_8 (Union[Unset, DataGroupingDimensionSpec]):
        level_9 (Union[Unset, DataGroupingDimensionSpec]):
    """

    level_1: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_2: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_3: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_4: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_5: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_6: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_7: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_8: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    level_9: Union[Unset, "DataGroupingDimensionSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        level_1: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_1, Unset):
            level_1 = self.level_1.to_dict()

        level_2: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_2, Unset):
            level_2 = self.level_2.to_dict()

        level_3: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_3, Unset):
            level_3 = self.level_3.to_dict()

        level_4: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_4, Unset):
            level_4 = self.level_4.to_dict()

        level_5: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_5, Unset):
            level_5 = self.level_5.to_dict()

        level_6: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_6, Unset):
            level_6 = self.level_6.to_dict()

        level_7: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_7, Unset):
            level_7 = self.level_7.to_dict()

        level_8: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_8, Unset):
            level_8 = self.level_8.to_dict()

        level_9: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.level_9, Unset):
            level_9 = self.level_9.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if level_1 is not UNSET:
            field_dict["level_1"] = level_1
        if level_2 is not UNSET:
            field_dict["level_2"] = level_2
        if level_3 is not UNSET:
            field_dict["level_3"] = level_3
        if level_4 is not UNSET:
            field_dict["level_4"] = level_4
        if level_5 is not UNSET:
            field_dict["level_5"] = level_5
        if level_6 is not UNSET:
            field_dict["level_6"] = level_6
        if level_7 is not UNSET:
            field_dict["level_7"] = level_7
        if level_8 is not UNSET:
            field_dict["level_8"] = level_8
        if level_9 is not UNSET:
            field_dict["level_9"] = level_9

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.data_grouping_dimension_spec import DataGroupingDimensionSpec

        d = src_dict.copy()
        _level_1 = d.pop("level_1", UNSET)
        level_1: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_1, Unset):
            level_1 = UNSET
        else:
            level_1 = DataGroupingDimensionSpec.from_dict(_level_1)

        _level_2 = d.pop("level_2", UNSET)
        level_2: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_2, Unset):
            level_2 = UNSET
        else:
            level_2 = DataGroupingDimensionSpec.from_dict(_level_2)

        _level_3 = d.pop("level_3", UNSET)
        level_3: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_3, Unset):
            level_3 = UNSET
        else:
            level_3 = DataGroupingDimensionSpec.from_dict(_level_3)

        _level_4 = d.pop("level_4", UNSET)
        level_4: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_4, Unset):
            level_4 = UNSET
        else:
            level_4 = DataGroupingDimensionSpec.from_dict(_level_4)

        _level_5 = d.pop("level_5", UNSET)
        level_5: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_5, Unset):
            level_5 = UNSET
        else:
            level_5 = DataGroupingDimensionSpec.from_dict(_level_5)

        _level_6 = d.pop("level_6", UNSET)
        level_6: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_6, Unset):
            level_6 = UNSET
        else:
            level_6 = DataGroupingDimensionSpec.from_dict(_level_6)

        _level_7 = d.pop("level_7", UNSET)
        level_7: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_7, Unset):
            level_7 = UNSET
        else:
            level_7 = DataGroupingDimensionSpec.from_dict(_level_7)

        _level_8 = d.pop("level_8", UNSET)
        level_8: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_8, Unset):
            level_8 = UNSET
        else:
            level_8 = DataGroupingDimensionSpec.from_dict(_level_8)

        _level_9 = d.pop("level_9", UNSET)
        level_9: Union[Unset, DataGroupingDimensionSpec]
        if isinstance(_level_9, Unset):
            level_9 = UNSET
        else:
            level_9 = DataGroupingDimensionSpec.from_dict(_level_9)

        data_grouping_configuration_spec = cls(
            level_1=level_1,
            level_2=level_2,
            level_3=level_3,
            level_4=level_4,
            level_5=level_5,
            level_6=level_6,
            level_7=level_7,
            level_8=level_8,
            level_9=level_9,
        )

        data_grouping_configuration_spec.additional_properties = d
        return data_grouping_configuration_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DuckdbFilesFormatType(str, Enum):
    AVRO = "avro"
    CSV = "csv"
    DELTA_LAKE = "delta_lake"
    ICEBERG = "iceberg"
    JSON = "json"
    PARQUET = "parquet"

    def __str__(self) -> str:
        return str(self.value)
